"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

var _Button = require("../Button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Alert = function Alert(props) {
  var children = props.children,
      className = props.className,
      icon = props.icon,
      title = props.title,
      toast = props.toast,
      theme = props.theme,
      onClickClose = props.onClickClose,
      rest = _objectWithoutProperties(props, ["children", "className", "icon", "title", "toast", "theme", "onClickClose"]);

  var sldsClasses = ['slds-notify', {
    'slds-notify_toast': toast
  }, {
    'slds-notify_alert slds-theme_alert-texture': !toast
  }, (0, _utils.getThemeClass)(theme), className];
  var iconEl;
  var iconContainerClasses;

  if (_react.default.isValidElement(icon)) {
    iconEl = _react.default.cloneElement(icon, {
      size: toast ? 'small' : 'x-small'
    });
    iconContainerClasses = ['slds-icon_container', {
      'slds-m-right_small slds-no-flex slds-align-top': toast
    }, {
      'slds-m-right_x-small': !toast
    }];
  }

  var alert = _react.default.createElement("div", _extends({}, rest, {
    className: (0, _classnames.default)(sldsClasses),
    role: toast ? 'status' : 'alert'
  }), _react.default.createElement("span", {
    className: "slds-assistive-text"
  }, title), iconEl && _react.default.createElement("span", {
    className: (0, _classnames.default)(iconContainerClasses)
  }, iconEl), toast ? _react.default.createElement("div", {
    className: "slds-notify__content"
  }, children) : children, onClickClose && _react.default.createElement("div", {
    className: "slds-notify__close"
  }, _react.default.createElement(_Button.IconButton, {
    flavor: "inverse",
    onClick: onClickClose,
    title: "Close"
  }, _react.default.createElement(_Button.ButtonIcon, {
    sprite: "utility",
    icon: "close",
    size: toast ? 'large' : 'small'
  }))));

  return toast ? _react.default.createElement("div", {
    className: "slds-notify_container slds-is-relative"
  }, alert) : alert;
};

Alert.defaultProps = {
  className: null,
  icon: null,
  toast: false,
  onClickClose: null,
  theme: 'info'
};
Alert.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * notification content
   */
  children: _propTypes.default.node.isRequired,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
  * IconSVG element
  */
  icon: _propTypes.default.element,

  /**
   * notification title (will be rendered as assistiveText)
   */
  title: _propTypes.default.string.isRequired,

  /**
   * render the notification as a toast
   */
  toast: _propTypes.default.bool,

  /**
   * function to call when close button is clicked
   */
  onClickClose: _propTypes.default.func,

  /**
   * notification theme (warning, error, offline, info (default))
   */
  theme: _propTypes.default.oneOf(_utils.THEMES)
} : {};
var _default = Alert;
exports.default = _default;