"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _ButtonIcon = _interopRequireDefault(require("./ButtonIcon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Button = _react.default.forwardRef(function (props, ref) {
  var buttonEl = props.buttonEl,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      href = props.href,
      icon = props.icon,
      iconPosition = props.iconPosition,
      sprite = props.sprite,
      stretch = props.stretch,
      title = props.title,
      rest = _objectWithoutProperties(props, ["buttonEl", "children", "className", "flavor", "href", "icon", "iconPosition", "sprite", "stretch", "title"]);

  var hasFlavor = flavor != null && flavor !== 'none';
  var sldsClasses = (0, _classnames.default)('slds-button', _defineProperty({}, "slds-button_".concat(flavor), hasFlavor), {
    'slds-button_stretch': stretch && flavor !== 'stretch'
  }, className);
  var ButtonEl = href ? 'a' : buttonEl || 'button';
  var position = iconPosition || 'left';
  var content = children || title;
  var isShortcut = !!icon && !!sprite;
  var isRightShortcut = isShortcut && position !== 'left';
  return _react.default.createElement(ButtonEl, _extends({}, rest, {
    className: sldsClasses,
    href: href,
    ref: ref,
    title: title
  }), isRightShortcut ? content : null, isShortcut && _react.default.createElement(_ButtonIcon.default, {
    position: position,
    icon: icon,
    sprite: sprite
  }), !isRightShortcut ? content : null);
});

Button.displayName = 'Button';
Button.defaultProps = {
  buttonEl: null,
  children: null,
  className: null,
  flavor: 'neutral',
  href: null,
  icon: null,
  iconPosition: null,
  sprite: null,
  stretch: false,
  title: null
};
Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Custom element (default is `button` or `a` when `href` is present)
   */
  buttonEl: _propTypes.default.string,

  /**
   * Used to set content in advanced use cases
   */
  children: _propTypes.default.node,

  /**
   * Title attribute. Will be button content if no children are set
   */
  title: _propTypes.default.string,

  /**
   * Shortcut to render a button with an icon. Used together with `sprite`
   */
  icon: _propTypes.default.string,

  /**
   * Shortcut to render a button with an icon. Used together with `icon`
   */
  sprite: _propTypes.default.string,

  /**
   *  Shortcut to render a button with an icon. Can be "left" or "right". Used together with `icon`
   */
  iconPosition: _propTypes.default.oneOf(['left', 'right']),

  /**
   * Optional additional className
   */
  className: _propTypes.default.string,

  /**
   * Can be either `neutral`, `brand`, `outline-brand`, `destructive`, `text-destructive`, `success` or `inverse`
   * Default to `neutral`, set to "none" or `null` explicitely to render a plain button
   * [DEPRECATED] `prop.stretch` should be used instd. of `flavor="stretch"`
   */
  flavor: _propTypes.default.oneOf(['brand', 'destructive', 'inverse', 'neutral', 'none', 'outline-brand', 'success', 'text-destructive', 'stretch']),

  /**
   * Optional href, renders as `a` when set
   */
  href: _propTypes.default.string,

  /**
   * Renders a full-width button
   */
  stretch: _propTypes.default.bool
} : {};
var _default = Button;
exports.default = _default;