"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MessageContent = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = require("prop-types");

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../utils");

var _MessageMeta = require("./MessageMeta");

var _MessageFile = require("./MessageFile");

var _MessageStatus = require("./MessageStatus");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/* eslint-disable react/jsx-one-expression-per-line */
var MessageContent = function MessageContent(_ref) {
  var attachment = _ref.attachment,
      author = _ref.author,
      error = _ref.error,
      isConsecutive = _ref.isConsecutive,
      isPastChat = _ref.isPastChat,
      message = _ref.message,
      meta = _ref.meta,
      type = _ref.type,
      rest = _objectWithoutProperties(_ref, ["attachment", "author", "error", "isConsecutive", "isPastChat", "message", "meta", "type"]);

  var hasAttachment = !!attachment;
  var isLink = hasAttachment && attachment.isLink;
  var isImage = hasAttachment && attachment.fileType === 'image';
  var isCoAuthor = type === _utils.CHAT_ITEM_TYPES.MESSAGE_OUTBOUND_AGENT;
  var isDeliveryFailure = type === _utils.CHAT_ITEM_TYPES.MESSAGE_DELIVERY_FAILURE;
  var isTyping = type === _utils.CHAT_ITEM_TYPES.MESSAGE_TYPING;
  var isUnsupportedType = type === _utils.CHAT_ITEM_TYPES.MESSAGE_UNSUPPORTED_TYPE;

  function getMessageSourceCssClass() {
    if (type === _utils.CHAT_ITEM_TYPES.MESSAGE_INBOUND || isUnsupportedType || isTyping) return 'inbound';
    if (isCoAuthor) return 'outbound-agent';
    return 'outbound';
  }

  var classNamesMessageText = (0, _classnames.default)([{
    'slds-chat-message__text': isLink || !hasAttachment
  }, _defineProperty({}, "slds-chat-message__text_".concat(getMessageSourceCssClass()), !isPastChat && (isLink || !hasAttachment)), {
    'slds-chat-message__text_unsupported-type': isUnsupportedType
  }, {
    'slds-chat-message__text_delivery-failure': isDeliveryFailure
  }, {
    'slds-chat-message__text_sneak-peek': isTyping && message
  }, {
    'slds-chat-message__image': !isLink && isImage
  }, _defineProperty({}, "slds-chat-message__image_".concat(getMessageSourceCssClass()), !isLink && isImage), {
    'slds-chat-message__file': hasAttachment && !isLink && !isImage
  }, _defineProperty({}, "slds-chat-message__file_".concat(getMessageSourceCssClass()), hasAttachment && !isLink && !isImage)]);

  if (isTyping) {
    return _react.default.createElement("div", {
      className: classNamesMessageText
    }, _react.default.createElement("span", {
      className: "slds-icon-typing slds-is-animated",
      title: meta
    }, _react.default.createElement("span", {
      className: "slds-icon-typing__dot"
    }), _react.default.createElement("span", {
      className: "slds-icon-typing__dot"
    }), _react.default.createElement("span", {
      className: "slds-icon-typing__dot"
    }), _react.default.createElement("span", {
      className: "slds-assistive-text"
    }, meta)), _react.default.createElement("span", {
      "aria-hidden": "true"
    }, message));
  }

  var messageMeta = _react.default.createElement(_MessageMeta.MessageMeta, _extends({
    author: author,
    isConsecutive: isConsecutive,
    isDeliveryFailure: isDeliveryFailure,
    isPastChat: isPastChat,
    meta: meta
  }, rest));

  var renderMessageStatus = function renderMessageStatus(msg) {
    return _react.default.createElement(_MessageStatus.MessageStatus, {
      message: msg,
      isDeliveryFailure: isDeliveryFailure,
      isUnsupportedType: isUnsupportedType
    });
  };

  return _react.default.createElement(_react.default.Fragment, null, isPastChat && messageMeta, _react.default.createElement("div", {
    className: classNamesMessageText
  }, hasAttachment && _react.default.createElement(_MessageFile.MessageFile, attachment), isUnsupportedType ? renderMessageStatus(message) : _react.default.createElement("span", null, message), isDeliveryFailure && _react.default.createElement("div", {
    className: "slds-chat-message__text_delivery-failure-reason",
    role: "alert"
  }, renderMessageStatus(error))), !isPastChat && messageMeta);
};
/* eslint-enable react/jsx-one-expression-per-line */


exports.MessageContent = MessageContent;
MessageContent.defaultProps = {
  attachment: null,
  error: null,
  message: null,
  meta: null
};
MessageContent.propTypes = process.env.NODE_ENV !== "production" ? {
  attachment: _propTypes.PropTypes.object,
  author: _propTypes.PropTypes.string.isRequired,
  error: _propTypes.PropTypes.string,
  isConsecutive: _propTypes.PropTypes.bool.isRequired,
  isPastChat: _propTypes.PropTypes.bool.isRequired,
  message: _propTypes.PropTypes.node,
  meta: _propTypes.PropTypes.node,
  type: _propTypes.PropTypes.string.isRequired
} : {};