"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BaseDropdownItem = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Icon = require("../../../Icon");

var _DropdownItemCore = require("./DropdownItemCore");

var _helpers = require("../../utils/helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var BaseDropdownItem = function BaseDropdownItem(props) {
  var highlight = props.highlight,
      icon = props.icon,
      id = props.id,
      isDisabled = props.isDisabled,
      isMultiSelect = props.isMultiSelect,
      isSelected = props.isSelected,
      isSelectedAssistiveLabel = props.isSelectedAssistiveLabel,
      label = props.label,
      meta = props.meta,
      rest = _objectWithoutProperties(props, ["highlight", "icon", "id", "isDisabled", "isMultiSelect", "isSelected", "isSelectedAssistiveLabel", "label", "meta"]);

  var iconEl;

  if (isSelected || icon) {
    var iconClassNames = (0, _classnames.default)([{
      'slds-icon_disabled': !!isDisabled
    }, 'slds-current-color']);
    iconEl = _react.default.createElement(_Icon.Icon, {
      className: iconClassNames,
      icon: isSelected ? 'check' : icon.icon,
      sprite: isSelected ? 'utility' : icon.sprite,
      size: "x-small"
    });
  }

  return _react.default.createElement(_DropdownItemCore.DropdownItemCore, _extends({}, rest, {
    className: "slds-listbox__option_plain",
    isDisabled: isDisabled,
    isSelected: isSelected,
    icon: _react.default.createElement("span", {
      className: "slds-media__figure slds-listbox__option-icon"
    }, iconEl)
  }), _react.default.createElement("span", {
    className: "slds-truncate",
    title: label
  }, isMultiSelect && isSelected && _react.default.createElement("span", {
    className: "slds-assistive-text"
  }, isSelectedAssistiveLabel), highlight.length > 0 ? (0, _helpers.defaultHighlighter)(label, highlight) : label), meta && _react.default.createElement("span", {
    className: "slds-listbox__option-meta"
  }, meta));
};

exports.BaseDropdownItem = BaseDropdownItem;
BaseDropdownItem.propTypes = process.env.NODE_ENV !== "production" ? {
  highlight: _propTypes.default.string,
  icon: _propTypes.default.shape({
    icon: _propTypes.default.string.isRequired,
    sprite: _propTypes.default.string.isRequired
  }),
  id: _propTypes.default.string.isRequired,
  isDisabled: _propTypes.default.bool,
  isMultiSelect: _propTypes.default.bool,
  isSelected: _propTypes.default.bool,
  isSelectedAssistiveLabel: _propTypes.default.string,
  label: _propTypes.default.string.isRequired,
  meta: _propTypes.default.node
} : {};
BaseDropdownItem.defaultProps = {
  highlight: '',
  icon: null,
  isDisabled: false,
  isMultiSelect: false,
  isSelected: false,
  isSelectedAssistiveLabel: 'Current Selection: ',
  meta: null
};