"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeInputAddHandler = exports.isSelectionReplace = exports.byItemId = exports.defaultHighlighter = exports.preventDefault = exports.getNextIndex = exports.scrollDropdown = void 0;

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var scrollDropdown = function scrollDropdown(parentNode, childNode) {
  var viewPortTop = parentNode.scrollTop;
  var viewPortBottom = viewPortTop + parentNode.offsetHeight;
  var selectedTop = childNode.offsetTop;
  var selectedBottom = selectedTop + childNode.offsetHeight;
  /* eslint-disable no-param-reassign */

  if (selectedBottom > viewPortBottom) {
    parentNode.scrollTop += selectedBottom - viewPortBottom;
  } else if (selectedTop < viewPortTop) {
    parentNode.scrollTop += selectedTop - viewPortTop;
  }
  /* eslint-enable no-param-reassign */

};

exports.scrollDropdown = scrollDropdown;

var getNextIndex = function getNextIndex(items, prevIndex) {
  var direction = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'desc';
  if (prevIndex == null) return getNextIndex(items, direction === 'desc' ? -1 : 0, direction);
  var len = items.length;

  var getIndexInBounds = function getIndexInBounds(nextIndex) {
    return (nextIndex % len + len) % len;
  };

  var nextIndex = getIndexInBounds(direction === 'desc' ? prevIndex + 1 : prevIndex - 1);
  var nextItem = items[nextIndex];
  return nextItem.isHeader ? getNextIndex(items, nextIndex, direction) : nextIndex;
};

exports.getNextIndex = getNextIndex;

var preventDefault = function preventDefault(evt) {
  return evt.preventDefault();
};

exports.preventDefault = preventDefault;

var makeHighlighter = function makeHighlighter(highlighter) {
  return function () {
    var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var search = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    var searchLen = search.length;
    if (searchLen === 0) return str;
    var splitLabel = str.toLowerCase().split(search.toLowerCase());
    var splitLen = splitLabel.length;
    if (splitLen < 2) return str;
    var startIndex = 0;
    var result = [];
    splitLabel.forEach(function (strPos, i) {
      var len = strPos.length;
      var origIndex = startIndex + len;
      var origStr = str.slice(startIndex, origIndex);
      startIndex = origIndex;
      var highlightEl = null;
      var highlightStr = '';

      if (i !== splitLen - 1) {
        var searchIndex = startIndex + searchLen;
        highlightStr = str.slice(startIndex, searchIndex);
        highlightEl = highlighter(highlightStr);
        startIndex = searchIndex;
      }

      result.push(_react.default.createElement(_react.default.Fragment, {
        key: "".concat(origStr).concat(highlightStr)
      }, origStr, highlightEl));
    });
    return result;
  };
};

var defaultHighlighter = makeHighlighter(function (str) {
  return _react.default.createElement("mark", null, str);
});
exports.defaultHighlighter = defaultHighlighter;

var byItemId = function byItemId(value) {
  return function (_ref) {
    var id = _ref.id;
    return id === value;
  };
};

exports.byItemId = byItemId;

var isSelectionReplace = function isSelectionReplace(opts) {
  var isMultiSelect = opts.isMultiSelect,
      selectedItems = opts.selectedItems;
  return !isMultiSelect && selectedItems.length > 0;
};

exports.isSelectionReplace = isSelectionReplace;

var makeInputAddHandler = function makeInputAddHandler(originalHandler, opts) {
  var isOpen = opts.isOpen,
      keyboardSelection = opts.keyboardSelection,
      onToggle = opts.onToggle,
      onSelect = opts.rawOnSelect,
      search = opts.search;
  return function (evt) {
    var key = evt.key;
    var isKeyboardAdd = isOpen && search !== '' && !keyboardSelection && key === 'Enter';

    if (isKeyboardAdd) {
      onSelect(search, {
        isAdd: true,
        isReplace: isSelectionReplace(opts),
        isRemove: false
      });
      onToggle(false);
      return true;
    }

    return originalHandler(evt);
  };
};

exports.makeInputAddHandler = makeInputAddHandler;