"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _FileActions = _interopRequireDefault(require("./FileActions"));

var _FileCaption = _interopRequireDefault(require("./FileCaption"));

var _FileExternalIcon = _interopRequireDefault(require("./FileExternalIcon"));

var _FileMedia = _interopRequireDefault(require("./FileMedia"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var RATIOS = process.env.NODE_ENV !== "production" ? ['1-by-1', '4-by-3', '16-by-9'] : {};

var File = function File(props) {
  var actions = props.actions,
      className = props.className,
      externalIcon = props.externalIcon,
      fileType = props.fileType,
      hideTitle = props.hideTitle,
      image = props.image,
      isLoading = props.isLoading,
      ratio = props.ratio,
      title = props.title,
      rest = _objectWithoutProperties(props, ["actions", "className", "externalIcon", "fileType", "hideTitle", "image", "isLoading", "ratio", "title"]);

  var sldsClasses = ['slds-file', 'slds-file_card', {
    'slds-has-title': !hideTitle
  }, {
    'slds-file_loading': isLoading
  }];
  var mediaClasses = ['slds-file__crop', _defineProperty({}, "slds-file__crop_".concat(ratio), ratio), className];
  return _react.default.createElement("div", {
    className: (0, _classnames.default)(sldsClasses)
  }, _react.default.createElement("figure", null, _react.default.createElement("a", _extends({}, rest, {
    className: (0, _classnames.default)(mediaClasses)
  }), _react.default.createElement(_FileMedia.default, {
    fileType: fileType,
    image: image,
    isLoading: isLoading,
    title: title
  })), !hideTitle && _react.default.createElement(_FileCaption.default, {
    fileType: fileType,
    hasActions: !!actions,
    title: title
  }), actions && _react.default.createElement(_FileActions.default, {
    hideTitle: hideTitle
  }, actions), externalIcon && _react.default.createElement(_FileExternalIcon.default, {
    externalIcon: externalIcon
  })));
};

File.defaultProps = {
  actions: null,
  className: null,
  externalIcon: null,
  fileType: 'image',
  image: null,
  isLoading: false,
  ratio: null,
  hideTitle: false
};
File.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * ButtonGroup with actions
   */
  actions: _propTypes.default.element,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * Renders an externalIcon for images from external services
   */
  externalIcon: _propTypes.default.shape({
    icon: _propTypes.default.string,
    sprite: _propTypes.default.string,
    title: _propTypes.default.string
  }),

  /**
   * fileType corresponding to SF doctype icon
   */
  fileType: _propTypes.default.string,

  /**
   * Determines if the title is shown
   */
  hideTitle: _propTypes.default.bool,

  /**
   * Image with src & alt
   */
  image: _propTypes.default.shape({
    alt: _propTypes.default.string,
    src: _propTypes.default.string
  }),

  /**
   * Indicate a loading image
   */
  isLoading: _propTypes.default.bool,

  /**
   * Optional ratio:   '1-by-1', '4-by-3', '16-by-9'
   */
  ratio: _propTypes.default.oneOf(RATIOS),

  /**
   * Image title
   */
  title: _propTypes.default.string.isRequired
} : {};
var _default = File;
exports.default = _default;