"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _reactDropzone = _interopRequireDefault(require("react-dropzone"));

var _Form = require("../Form");

var _Button = require("../Button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var preventDefault = function preventDefault(e) {
  return e.preventDefault();
};

var FileSelector = function FileSelector(_ref) {
  var accept = _ref.accept,
      buttonText = _ref.buttonText,
      id = _ref.id,
      error = _ref.error,
      fatalError = _ref.fatalError,
      label = _ref.label,
      minSize = _ref.minSize,
      maxSize = _ref.maxSize,
      multiple = _ref.multiple,
      onDragEnter = _ref.onDragEnter,
      onDragLeave = _ref.onDragLeave,
      onDrop = _ref.onDrop,
      selectorText = _ref.selectorText,
      selectorType = _ref.selectorType;
  var errorStr = fatalError || error;
  var fileSelectorClasses = ['slds-file-selector', "slds-file-selector_".concat(selectorType)];
  var primaryLabelId = "".concat(id, "-primary-label");
  var secondaryLabelId = "".concat(id, "-secondary-label");
  return _react.default.createElement(_Form.FormElement, {
    error: errorStr
  }, _react.default.createElement("span", {
    className: "slds-form-element__label",
    id: primaryLabelId
  }, label), _react.default.createElement(_Form.FormElementControl, null, _react.default.createElement("div", {
    className: (0, _classnames.default)(fileSelectorClasses)
  }, _react.default.createElement(_reactDropzone.default, {
    accept: accept,
    disabled: !!fatalError,
    minSize: minSize,
    maxSize: maxSize,
    multiple: multiple,
    onDrop: onDrop,
    onDragEnter: onDragEnter,
    onDragLeave: onDragLeave
  }, function (_ref2) {
    var getRootProps = _ref2.getRootProps,
        getInputProps = _ref2.getInputProps,
        isDragActive = _ref2.isDragActive;
    return _react.default.createElement("div", getRootProps({
      className: (0, _classnames.default)(['slds-file-selector__dropzone', {
        'slds-has-drag-over': isDragActive && !fatalError
      }])
    }), _react.default.createElement("input", getInputProps({
      'aria-labelledby': "".concat(primaryLabelId, " ").concat(secondaryLabelId),
      className: 'slds-file-selector__input slds-assistive-text',
      disabled: fatalError,
      id: id
    })), _react.default.createElement("label", {
      className: "slds-file-selector__body",
      htmlFor: id // Fixes dialog not working due to default `label<>input` event handling (Safari,Chrome)
      ,
      onClick: preventDefault,
      id: secondaryLabelId
    }, _react.default.createElement(_Button.Button, {
      buttonEl: "span",
      className: "slds-file-selector__button",
      flavor: "neutral",
      icon: "upload",
      sprite: "utility",
      title: buttonText
    }), _react.default.createElement("span", {
      className: "slds-file-selector__text slds-medium-show"
    }, selectorText)));
  }))), _react.default.createElement(_Form.FormElementError, {
    error: errorStr,
    id: id
  }));
};

FileSelector.defaultProps = {
  accept: null,
  error: null,
  fatalError: null,
  minSize: 0,
  maxSize: null,
  multiple: false,
  onDragEnter: null,
  onDragLeave: null,
  selectorType: 'files'
};
FileSelector.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Maps to the HTML5 `accept` attribute. Used to narrow down allowed file types
   */
  accept: _propTypes.default.string,

  /**
   * Button title
   */
  buttonText: _propTypes.default.string.isRequired,

  /**
   * Error displayed below form. This should be used for informational messages as it does not disable the dropzone
   */
  error: _propTypes.default.string,

  /**
   * Takes precedence over `error` and _will_ disable the dropzone
   */
  fatalError: _propTypes.default.string,

  /**
   * Id of this file selector
   */
  id: _propTypes.default.string.isRequired,

  /**
   * Top-level label
   */
  label: _propTypes.default.string.isRequired,

  /**
   * Minimum file size (in bytes)
   */
  minSize: _propTypes.default.number,

  /**
   * Maximum file size (in bytes)
   */
  maxSize: _propTypes.default.number,

  /**
   * Maps to the HTML5 `multiple` attribute
   */
  multiple: _propTypes.default.bool,

  /**
   * `onDragEnter` passed to `Dropzone`. Called with:
   *   - `event`
   */
  onDragEnter: _propTypes.default.func,

  /**
   * `onDragLeave` passed to `Dropzone`. Called with:
   *   - `event`
   */
  onDragLeave: _propTypes.default.func,

  /**
   * `onDrop` passed to `Dropzone`. Called with:
   *   - `acceptedFiles`
   *   - `rejectedFiles`
   *   - `event`
   */
  onDrop: _propTypes.default.func.isRequired,

  /**
   * Addl. text rendered next to the button
   */
  selectorText: _propTypes.default.string.isRequired,

  /**
   * Toggles display style
   */
  selectorType: _propTypes.default.oneOf(['files', 'images'])
} : {};
var _default = FileSelector;
exports.default = _default;