"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _FormElement = _interopRequireDefault(require("./FormElement"));

var _FormElementControl = _interopRequireDefault(require("./FormElementControl"));

var _FormElementError = _interopRequireDefault(require("./FormElementError"));

var _FormElementLabel = _interopRequireDefault(require("./FormElementLabel"));

var _utils = require("../../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var CheckboxGroup = function CheckboxGroup(props) {
  var children = props.children,
      className = props.className,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      id = props.id,
      label = props.label,
      onChange = props.onChange,
      required = props.required,
      rest = _objectWithoutProperties(props, ["children", "className", "error", "hideErrorMessage", "id", "label", "onChange", "required"]);

  var wrapChildrenWithError = function wrapChildrenWithError() {
    if (!error || hideErrorMessage) {
      return children;
    }

    return _react.default.Children.map(children, function (child) {
      return _react.default.cloneElement(child, {
        'aria-describedby': (0, _utils.getUniqueHash)(error, id)
      });
    });
  };

  return _react.default.createElement(_FormElement.default, _extends({}, rest, {
    className: className,
    error: error,
    fieldset: true,
    id: id,
    onChange: onChange,
    required: required
  }), _react.default.createElement(_FormElementLabel.default, {
    legend: true,
    required: required,
    label: label,
    id: id
  }), _react.default.createElement(_FormElementControl.default, null, wrapChildrenWithError()), !hideErrorMessage && _react.default.createElement(_FormElementError.default, {
    error: error,
    id: id
  }));
};

CheckboxGroup.defaultProps = {
  className: null,
  error: null,
  hideErrorMessage: false,
  onChange: function onChange() {},
  required: false
};
CheckboxGroup.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * The checkboxes to render
   */
  children: _propTypes.default.node.isRequired,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * renders an error for the fieldset
   */
  error: _propTypes.default.string,

  /**
   * hides the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * id of the fieldset
   */
  id: _propTypes.default.string.isRequired,

  /**
   * label
   */
  label: _propTypes.default.node.isRequired,

  /**
   * onchange handler
   */
  onChange: _propTypes.default.func,

  /**
   * adds required attribute to the fieldset
   */
  required: _propTypes.default.bool
} : {};
var _default = CheckboxGroup;
exports.default = _default;