"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _FormElement = _interopRequireDefault(require("./FormElement"));

var _FormElementControl = _interopRequireDefault(require("./FormElementControl"));

var _FormElementError = _interopRequireDefault(require("./FormElementError"));

var _FormElementLabel = _interopRequireDefault(require("./FormElementLabel"));

var _InputRaw = _interopRequireDefault(require("./InputRaw"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Input = _react.default.forwardRef(function (props, ref) {
  var error = props.error,
      errorIcon = props.errorIcon,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      iconLeft = props.iconLeft,
      iconRight = props.iconRight,
      id = props.id,
      isStatic = props.isStatic,
      label = props.label,
      placeholder = props.placeholder,
      readOnly = props.readOnly,
      required = props.required,
      showSpinner = props.showSpinner,
      value = props.value,
      rest = _objectWithoutProperties(props, ["error", "errorIcon", "hideErrorMessage", "hideLabel", "iconLeft", "iconRight", "id", "isStatic", "label", "placeholder", "readOnly", "required", "showSpinner", "value"]);

  var hasIconLeft = !!iconLeft || error && errorIcon;
  var hasIconRight = !!iconRight || !!showSpinner;
  return _react.default.createElement(_FormElement.default, {
    isStatic: isStatic,
    required: required,
    error: error
  }, _react.default.createElement(_FormElementLabel.default, {
    hideLabel: hideLabel,
    id: id,
    label: label,
    readOnly: isStatic,
    required: required
  }), _react.default.createElement(_FormElementControl.default, {
    hasIconLeft: hasIconLeft,
    hasIconRight: hasIconRight
  }, !isStatic ? _react.default.createElement(_InputRaw.default, _extends({
    error: error,
    errorIcon: errorIcon,
    hideErrorMessage: hideErrorMessage,
    iconLeft: iconLeft,
    iconRight: iconRight,
    id: id,
    label: label,
    placeholder: placeholder,
    readOnly: readOnly,
    ref: ref,
    required: required,
    showSpinner: showSpinner,
    value: value
  }, rest)) : _react.default.createElement("div", {
    className: "slds-form-element__static"
  }, value)), !hideErrorMessage && _react.default.createElement(_FormElementError.default, {
    error: error,
    id: id
  }));
});

Input.displayName = 'Input';
Input.defaultProps = {
  bare: false,
  className: null,
  disabled: false,
  error: null,
  errorIcon: false,
  hideErrorMessage: false,
  hideLabel: false,
  iconLeft: null,
  iconRight: null,
  iconRightOnClick: function iconRightOnClick() {},
  label: null,
  onChange: function onChange() {},
  onFocus: function onFocus() {},
  onKeyPress: function onKeyPress() {},
  placeholder: null,
  readOnly: null,
  role: null,
  required: false,
  showSpinner: false,
  type: 'text',
  value: undefined
};
Input.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * renders a bare input
   */
  bare: _propTypes.default.bool,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * adds disabled attribute to the input field
   */
  disabled: _propTypes.default.bool,

  /**
   * renders an error for the input. shows an error messsage if error is a string,
   * just marks the input if its a boolean.
   */
  error: _propTypes.default.string,

  /**
   * renders an additional error icon if an error is set
   */
  errorIcon: _propTypes.default.bool,

  /**
   * hides the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: _propTypes.default.bool,

  /**
   * icon rendered on the left side of the input (from utility sprite)
   */
  iconLeft: _propTypes.default.string,

  /**
   * icon rendered on the right side of the input (from utility sprite)
   */
  iconRight: _propTypes.default.string,

  /**
   * onClick handler for the right icon
   */
  iconRightOnClick: _propTypes.default.func,

  /**
   * id of the input field
   */
  id: _propTypes.default.string.isRequired,

  /**
   * Renders in a static, "view" mode
   */
  isStatic: _propTypes.default.bool,

  /**
   * label for the input
   */
  label: _propTypes.default.node,

  /**
   * onChange handler for input
   */
  onChange: _propTypes.default.func,

  /**
   * onFocus handler for input
   */
  onFocus: _propTypes.default.func,

  /**
   * onKeyPress handler
   */
  onKeyPress: _propTypes.default.func,

  /**
   * placeholder for the input
   */
  placeholder: _propTypes.default.string,

  /**
   * Renders a read-only input element
   */
  readOnly: _propTypes.default.bool,

  /**
   * adds required attribute to input and label
   */
  required: _propTypes.default.bool,

  /**
   * role of the input field
   */
  role: _propTypes.default.string,

  /**
   * whether to show a spinner element inside the field, on the right end
   */
  showSpinner: _propTypes.default.bool,

  /**
   * input type. all HTML5 types are allowed, defaults to "text"
   * text, password, datetime, datetime-local, date, month, time, week, number, email, url, search, tel, and color
   */
  type: _propTypes.default.string,

  /**
   * value of the input field
   */
  value: _propTypes.default.string
} : {};
var _default = Input;
exports.default = _default;