"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var RadioRaw = function RadioRaw(props) {
  var checked = props.checked,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      name = props.name,
      onChange = props.onChange,
      required = props.required,
      rest = _objectWithoutProperties(props, ["checked", "className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "name", "onChange", "required"]);

  var renderRadio = function renderRadio() {
    return _react.default.createElement("input", _extends({
      "aria-describedby": error && !hideErrorMessage ? (0, _utils.getUniqueHash)(error, id) : null
    }, rest, {
      checked: checked,
      className: className,
      disabled: disabled,
      id: id,
      name: name,
      onChange: onChange,
      type: "radio"
    }));
  };

  var labelClasses = ['slds-form-element__label', {
    'slds-assistive-text': hideLabel
  }];

  var renderLabel = function renderLabel() {
    return _react.default.createElement("label", {
      className: "slds-radio__label",
      htmlFor: id
    }, _react.default.createElement("span", {
      className: "slds-radio_faux"
    }), _react.default.createElement("span", {
      className: (0, _classnames.default)(labelClasses)
    }, label));
  };

  var renderRequired = function renderRequired() {
    if (!required) {
      return null;
    }

    return _react.default.createElement("abbr", {
      className: "slds-required",
      title: "required"
    }, "*");
  };

  return _react.default.createElement("span", {
    className: "slds-radio"
  }, renderRequired(), renderRadio(), renderLabel());
};

RadioRaw.defaultProps = {
  checked: null,
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: function onChange() {},
  required: false
};
RadioRaw.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * checks the radio button
   */
  checked: _propTypes.default.bool,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
  * adds disabled attribute
   */
  disabled: _propTypes.default.bool,

  /**
  * renders an error for the radio
   */
  error: _propTypes.default.string,

  /**
   * hides the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: _propTypes.default.bool,

  /**
   * id of the radio
   */
  id: _propTypes.default.string.isRequired,

  /**
   * label
   */
  label: _propTypes.default.node.isRequired,

  /**
   * radio group name
   */
  name: _propTypes.default.string.isRequired,

  /**
   * onChange handler
   */
  onChange: _propTypes.default.func,

  /**
   * adds required attribute to the radio
   */
  required: _propTypes.default.bool
} : {};
var _default = RadioRaw;
exports.default = _default;