"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

var _FormElement = _interopRequireDefault(require("./FormElement"));

var _FormElementControl = _interopRequireDefault(require("./FormElementControl"));

var _FormElementError = _interopRequireDefault(require("./FormElementError"));

var _FormElementLabel = _interopRequireDefault(require("./FormElementLabel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Select = function Select(props) {
  var children = props.children,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      multiple = props.multiple,
      onChange = props.onChange,
      required = props.required,
      rest = _objectWithoutProperties(props, ["children", "className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "multiple", "onChange", "required"]);

  var sldsClasses = ['slds-select', className];

  var renderSelect = function renderSelect() {
    var select = _react.default.createElement("select", _extends({}, rest, {
      id: id,
      className: (0, _classnames.default)(sldsClasses),
      onChange: onChange,
      multiple: multiple,
      required: required,
      disabled: disabled,
      "aria-describedby": error && !hideErrorMessage ? (0, _utils.getUniqueHash)(error, id) : null
    }), children);

    if (multiple) {
      return select;
    }

    return _react.default.createElement("div", {
      className: "slds-select_container"
    }, select);
  };

  return _react.default.createElement(_FormElement.default, {
    required: required,
    error: error
  }, _react.default.createElement(_FormElementLabel.default, {
    label: label,
    id: id,
    hideLabel: hideLabel,
    required: required
  }), _react.default.createElement(_FormElementControl.default, null, renderSelect()), !hideErrorMessage && _react.default.createElement(_FormElementError.default, {
    error: error,
    id: id
  }));
};

Select.defaultProps = {
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  multiple: false,
  onChange: function onChange() {},
  required: false
};
Select.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * options & optgroups of the select
   */
  children: _propTypes.default.node.isRequired,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * adds disabled attribute to the select
   */
  disabled: _propTypes.default.bool,

  /**
  * renders an error for the select
   */
  error: _propTypes.default.string,

  /**
   * hides the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: _propTypes.default.bool,

  /**
   * id of the select
   */
  id: _propTypes.default.string.isRequired,

  /**
   * label for the select
   */
  label: _propTypes.default.node.isRequired,

  /**
   * adds the multiple attribute to the select
   */
  multiple: _propTypes.default.bool,

  /**
   * onChange handler for the select
   */
  onChange: _propTypes.default.func,

  /**
   * adds required attribute to the select field and label
   */
  required: _propTypes.default.bool
} : {};
var _default = Select;
exports.default = _default;