"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _FormElement = _interopRequireDefault(require("./FormElement"));

var _FormElementControl = _interopRequireDefault(require("./FormElementControl"));

var _FormElementError = _interopRequireDefault(require("./FormElementError"));

var _FormElementLabel = _interopRequireDefault(require("./FormElementLabel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var renderLabel = function renderLabel(label, min, max) {
  return _react.default.createElement("span", {
    className: "slds-slider-label"
  }, _react.default.createElement("span", {
    className: "slds-slider-label__label"
  }, label), _react.default.createElement("span", {
    className: "slds-slider-label__range"
  }, "".concat(min, " - ").concat(max)));
};

var renderControl = function renderControl(onChange, id, value, min, max, step, size, disabled, vertical) {
  var baseClass = 'slds-slider';
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_vertical"), vertical), _defineProperty({}, "slds-size_".concat(size), !!size && !vertical)];
  return _react.default.createElement("div", {
    className: (0, _classnames.default)(sldsClasses)
  }, _react.default.createElement("input", {
    className: "slds-slider__range",
    type: "range",
    id: id,
    value: value,
    min: min,
    max: max,
    step: step,
    disabled: disabled,
    onChange: onChange
  }), _react.default.createElement("span", {
    className: "slds-slider__value",
    "aria-hidden": "true"
  }, value));
};

var Slider = function Slider(props) {
  var label = props.label,
      value = props.value,
      onChange = props.onChange,
      min = props.min,
      max = props.max,
      step = props.step,
      id = props.id,
      size = props.size,
      disabled = props.disabled,
      vertical = props.vertical,
      error = props.error,
      hideLabel = props.hideLabel,
      hideErrorMessage = props.hideErrorMessage,
      className = props.className;
  return _react.default.createElement(_FormElement.default, {
    error: error,
    className: className
  }, _react.default.createElement(_FormElementLabel.default, {
    label: renderLabel(label, min, max),
    id: id,
    hideLabel: hideLabel
  }), _react.default.createElement(_FormElementControl.default, null, renderControl(onChange, id, value, min, max, step, size, disabled, vertical)), !hideErrorMessage && _react.default.createElement(_FormElementError.default, {
    error: error,
    id: id
  }));
};

Slider.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * id of the slider
   */
  id: _propTypes.default.string.isRequired,

  /**
   * current value of the slider
   */
  value: _propTypes.default.number.isRequired,

  /**
   * minimum value
   */
  min: _propTypes.default.number,

  /**
   * maximum value
   */
  max: _propTypes.default.number,

  /**
   * step value
   */
  step: _propTypes.default.number,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * adds disabled attribute to the slider
   */
  disabled: _propTypes.default.bool,

  /**
   * render slider vertically
   */
  vertical: _propTypes.default.bool,

  /**
  * renders an error for the slider
   */
  error: _propTypes.default.string,

  /**
   * hides the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: _propTypes.default.bool,

  /**
   * label for the select
   */
  label: _propTypes.default.node,

  /**
   * onChange handler for the slider
   */
  onChange: _propTypes.default.func,

  /**
   * slider sizes: x-small, small, medium, large
   */
  size: _propTypes.default.oneOf(['x-small', 'small', 'medium', 'large'])
} : {};
Slider.defaultProps = {
  label: null,
  min: 0,
  max: 100,
  step: null,
  size: null,
  vertical: false,
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: Function.prototype
};
var _default = Slider;
exports.default = _default;