"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

var _FormElement = _interopRequireDefault(require("./FormElement"));

var _FormElementControl = _interopRequireDefault(require("./FormElementControl"));

var _FormElementError = _interopRequireDefault(require("./FormElementError"));

var _FormElementLabel = _interopRequireDefault(require("./FormElementLabel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Textarea = function Textarea(props) {
  var className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      onChange = props.onChange,
      placeholder = props.placeholder,
      required = props.required,
      readOnly = props.readOnly,
      rest = _objectWithoutProperties(props, ["className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "onChange", "placeholder", "required", "readOnly"]);

  var renderContent = function renderContent() {
    if (readOnly) {
      return _react.default.createElement("div", _extends({}, rest, {
        className: "slds-form-element__static slds-text-longform"
      }), _react.default.createElement("p", null, placeholder));
    }

    var sldsClasses = ['slds-textarea', className];
    return _react.default.createElement("textarea", _extends({}, rest, {
      className: (0, _classnames.default)(sldsClasses),
      id: id,
      onChange: onChange,
      placeholder: placeholder,
      disabled: disabled,
      required: required,
      "aria-describedby": error && !hideErrorMessage ? (0, _utils.getUniqueHash)(error, id) : null
    }));
  };

  return _react.default.createElement(_FormElement.default, {
    className: readOnly ? className : null,
    required: required,
    error: error
  }, _react.default.createElement(_FormElementLabel.default, {
    label: label,
    id: id,
    required: required,
    hideLabel: hideLabel,
    readOnly: readOnly
  }), _react.default.createElement(_FormElementControl.default, {
    className: (0, _classnames.default)({
      'slds-border_bottom': readOnly
    })
  }, renderContent()), !hideErrorMessage && _react.default.createElement(_FormElementError.default, {
    error: error,
    id: id
  }));
};

Textarea.defaultProps = {
  className: null,
  disabled: null,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: function onChange() {},
  readOnly: false,
  required: false
};
Textarea.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
  * adds disabled attribute to the textarea
   */
  disabled: _propTypes.default.bool,

  /**
  * renders an error for the textarea
   */
  error: _propTypes.default.string,

  /**
   * renders the error message
   */
  hideErrorMessage: _propTypes.default.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: _propTypes.default.bool,

  /**
   * id of the textarea
   */
  id: _propTypes.default.string.isRequired,

  /**
   * label for the textarea
   */
  label: _propTypes.default.node.isRequired,

  /**
   * onChange handler for the textarea
   */
  onChange: _propTypes.default.func,

  /**
   * textarea placeholder
   */
  placeholder: _propTypes.default.string.isRequired,

  /**
   * renders a static textarea output instead
   */
  readOnly: _propTypes.default.bool,

  /**
   * adds required attribute to the textarea
   */
  required: _propTypes.default.bool
} : {};
var _default = Textarea;
exports.default = _default;