"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.gutterSizes = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var gutterSizes = ['xxx-small', 'xx-small', 'x-small', 'small', 'medium', 'large', 'x-large', 'xx-large'];
exports.gutterSizes = gutterSizes;

var Grid = function Grid(props) {
  var align = props.align,
      El = props.as,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      gutters = props.gutters,
      guttersDirect = props.guttersDirect,
      pullPadding = props.pullPadding,
      verticalAlign = props.verticalAlign,
      wrap = props.wrap,
      rest = _objectWithoutProperties(props, ["align", "as", "children", "className", "flavor", "gutters", "guttersDirect", "pullPadding", "verticalAlign", "wrap"]);

  var baseClass = 'slds-grid';
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_align-").concat(align), !!align), _defineProperty({}, "".concat(baseClass, "_vertical-align-").concat(verticalAlign), !!verticalAlign), _defineProperty({}, "".concat(baseClass, "_pull-padded-").concat(pullPadding), !!pullPadding), (0, _utils.applyDecorators)(flavor, 'grid'), {
    'slds-wrap': !!wrap
  }, className];
  var guttersBaseClass = guttersDirect ? 'slds-gutters_direct' : 'slds-gutters';

  if (gutters === true || guttersDirect === true && gutters === false) {
    sldsClasses.push(guttersBaseClass);
  } else if (gutters && gutters !== true) {
    sldsClasses.push("".concat(guttersBaseClass).concat(guttersDirect ? '-' : '_').concat(gutters));
  }

  return _react.default.createElement(El, _extends({}, rest, {
    className: (0, _classnames.default)(sldsClasses)
  }), children);
};

Grid.defaultProps = {
  align: null,
  as: 'div',
  children: null,
  className: null,
  gutters: null,
  guttersDirect: false,
  flavor: [],
  pullPadding: null,
  verticalAlign: null,
  wrap: false
};
Grid.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Allows using an arbitrary DOM element as container
   */
  as: _propTypes.default.string,

  /**
   * grid content
   */
  children: _propTypes.default.node,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * flavor: array of flavors, you can also provide a single flavor string.
   * Flavors: frame, vertical, reverse, vertical-reverse
   */
  flavor: (0, _utils.decoratorProp)(['frame', 'vertical', 'reverse', 'vertical-reverse', 'vertical-stretch']),

  /**
   * Controls how columns are aligned horizontally.
   * Can either either: center, end, space, spread
   */
  align: _propTypes.default.oneOf(['center', 'end', 'space', 'spread']),

  /**
   * Automatic gutters for all children.
   * Can either be true or any valid slds size string (xxx-small to xx-large)
   */
  gutters: _propTypes.default.oneOf([true, false].concat(gutterSizes)),

  /**
   * When true, gutters will only be applied to direct children. Use in combination with `gutters`
   */
  guttersDirect: _propTypes.default.bool,

  /**
   * Controls how columns are aligned vertically.
   * Can either either: center, end, space
   */
  verticalAlign: _propTypes.default.oneOf(['center', 'end', 'start']),

  /**
   * Normalizes the padding when nesting a grid in a region with .slds-p-horizontal_${size}
   * Note: Not needed when using gutters prop
   */
  pullPadding: _propTypes.default.oneOf(gutterSizes),

  /**
   * Allows columns to wrap when they exceed 100% of their parent’s width
   * Default Behavior is: Keeps columns on one line.
   */
  wrap: _propTypes.default.bool
} : {};
var _default = Grid;
exports.default = _default;