"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _isString = _interopRequireDefault(require("lodash-es/isString"));

var _Icon = require("../Icon");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var nonCapturing = {
  pointerEvents: 'none'
};
/* eslint-disable react/prop-types */

var leftIconElem = function leftIconElem(_ref) {
  var alwaysDisplay = _ref.alwaysDisplay,
      sprite = _ref.sprite,
      icon = _ref.icon;
  var iconClasses = [{
    'slds-icon_selected': !alwaysDisplay
  }, {
    'slds-icon-text-default': !alwaysDisplay
  }, {
    'slds-m-right_x-small': !alwaysDisplay
  }, {
    'slds-m-right_small': alwaysDisplay
  }, {
    'slds-icon': alwaysDisplay
  }];
  return _react.default.createElement(_Icon.IconSVG, {
    className: (0, _classnames.default)(iconClasses),
    icon: icon,
    size: alwaysDisplay ? 'small' : 'x-small',
    sprite: sprite
  });
};

var rightIconElem = function rightIconElem(_ref2) {
  var icon = _ref2.icon,
      sprite = _ref2.sprite;
  var iconClasses = ['slds-icon-selected', 'slds-icon-text-default', 'slds-m-left_small', 'slds-shrink-none'];
  return _react.default.createElement(_Icon.IconSVG, {
    className: (0, _classnames.default)(iconClasses),
    icon: icon,
    size: "x-small",
    sprite: sprite,
    style: nonCapturing
  });
};
/* eslint-enable */


var MenuItem = function MenuItem(props) {
  var children = props.children,
      className = props.className,
      dataValue = props['data-value'],
      divider = props.divider,
      id = props.id,
      leftIcon = props.leftIcon,
      rightIcon = props.rightIcon,
      selected = props.selected,
      title = props.title,
      rest = _objectWithoutProperties(props, ["children", "className", "data-value", "divider", "id", "leftIcon", "rightIcon", "selected", "title"]);

  var sldsClasses = ['slds-dropdown__item', {
    'slds-has-divider_top-space': divider
  }, {
    'slds-is-selected': selected
  }, className];
  var assistiveTitle = title || (0, _isString.default)(children) && children || null;
  var role = selected === null ? 'menuitem' : 'menuitemcheckbox'; // if selected true or false, it's a menuitemcheckbox, else it's a menuitem

  return _react.default.createElement("li", _extends({}, rest, {
    className: (0, _classnames.default)(sldsClasses),
    role: "presentation"
  }), _react.default.createElement("a", {
    "aria-checked": selected,
    "data-value": dataValue,
    role: role
  }, _react.default.createElement("span", {
    className: "slds-truncate",
    style: nonCapturing,
    title: assistiveTitle
  }, leftIcon && leftIconElem(leftIcon), children), rightIcon && rightIconElem(rightIcon)));
};

MenuItem.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * The content of a menu item
   */
  children: _propTypes.default.node.isRequired,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * data-value is required when using onSelect on parent
   */
  'data-value': _propTypes.default.string,

  /**
   * set to true if a divider should appear above this list item
   */
  divider: _propTypes.default.bool,

  /**
   * left icon that is only shown when selected is true
   */
  leftIcon: _propTypes.default.shape({
    icon: _propTypes.default.string.isRequired,
    sprite: _propTypes.default.string.isRequired,
    alwaysDisplay: _propTypes.default.bool
  }),

  /**
   * right icon that is always shown
   */
  rightIcon: _propTypes.default.shape({
    icon: _propTypes.default.string,
    sprite: _propTypes.default.string.isRequired
  }),

  /**
   * sets this item into a selection state that displays the leftIcon
   */
  selected: _propTypes.default.bool,

  /**
   * id should be set by parent element
   */
  id: _propTypes.default.string,

  /**
   * Assistive title. Falls back to `children` if children is a string
   */
  title: _propTypes.default.string
} : {};
MenuItem.defaultProps = {
  className: null,
  'data-value': null,
  divider: false,
  leftIcon: null,
  rightIcon: null,
  selected: null,
  title: null,
  id: null
};
var _default = MenuItem;
exports.default = _default;