"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("./utils");

var _Icon = require("../Icon");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var getIconForStatus = function getIconForStatus(status, labels) {
  if (!status) return null;
  if (status === 'expired') return _react.default.createElement(_Icon.Icon, {
    sprite: "utility",
    icon: "error",
    title: labels.expired
  });
  if (status === 'warning') return _react.default.createElement(_Icon.Icon, {
    sprite: "utility",
    icon: "warning",
    title: labels.warning
  });
  return _react.default.createElement(_Icon.Icon, {
    sprite: "utility",
    icon: "check",
    title: labels.complete
  });
};

var getPath = function getPath(progress, isComplete, variant) {
  var prefix = 'M 1 0 A 1 1 0';
  var postfix = 'L 0 0';
  var d = "".concat(prefix, " 1 1 1 -2.4492935982947064e-16 ").concat(postfix);

  if (!isComplete) {
    var deg = 2 * Math.PI * progress;
    var isLong = progress >= 0.5 ? '1' : '0';
    d = variant === 'fill' ? "".concat(prefix, " ").concat(isLong, " 0 ").concat(Math.cos(deg), " ").concat(-Math.sin(deg), " ").concat(postfix) : "".concat(prefix, " ").concat(isLong, " 1 ").concat(Math.cos(deg), " ").concat(Math.sin(deg), " ").concat(postfix);
  }

  return _react.default.createElement("path", {
    className: "slds-progress-ring__path",
    d: d
  });
};

var ProgressRing = function ProgressRing(props) {
  var assistiveLabels = props.assistiveLabels,
      children = props.children,
      className = props.className,
      complete = props.complete,
      customIcon = props.customIcon,
      min = props.min,
      max = props.max,
      progress = props.progress,
      size = props.size,
      status = props.status,
      variant = props.variant,
      rest = _objectWithoutProperties(props, ["assistiveLabels", "children", "className", "complete", "customIcon", "min", "max", "progress", "size", "status", "variant"]);

  var baseClass = 'slds-progress-ring';
  var percComplete = (0, _utils.getClampedProgress)(progress, min, max);
  var isForceComplete = complete === true || complete === 'auto' && percComplete === 100;
  var currentStatus = isForceComplete ? 'complete' : status;
  var content = children || (!currentStatus && customIcon ? customIcon : getIconForStatus(currentStatus, assistiveLabels));
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_").concat(currentStatus), !!currentStatus), className, _defineProperty({}, "".concat(baseClass, "_").concat(size), !!size)];
  return _react.default.createElement("div", _extends({}, rest, {
    className: (0, _classnames.default)(sldsClasses)
  }), _react.default.createElement("div", {
    className: "slds-progress-ring__progress",
    role: "progressbar",
    "aria-valuemin": min,
    "aria-valuemax": max,
    "aria-valuenow": percComplete
  }, _react.default.createElement("svg", {
    viewBox: "-1 -1 2 2"
  }, getPath(percComplete / 100, isForceComplete, variant))), _react.default.createElement("div", {
    className: "slds-progress-ring__content"
  }, content));
};

ProgressRing.defaultProps = {
  assistiveLabels: {
    complete: 'Complete',
    expired: 'Expired',
    warning: 'Warning'
  },
  className: null,
  complete: 'auto',
  customIcon: null,
  min: 0,
  max: 100,
  progress: 0,
  size: null,
  status: null,
  variant: 'fill',
  children: null
};
ProgressRing.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Assistive labels for statuses
   */
  assistiveLabels: _propTypes.default.shape({
    expired: _propTypes.default.string.isRequired,
    warning: _propTypes.default.string.isRequired,
    complete: _propTypes.default.string.isRequired
  }),

  /**
   * If provided, children has precedence over the customIcon and status prop
   */
  children: _propTypes.default.node,

  /**
   * Controls when the complete state is rendered. Can either be a boolean value or 'auto'
   * 'auto': Sets complete once progress >= max
   */
  complete: _propTypes.default.oneOf([true, false, 'auto']),

  /**
   * (Optional) ClassName
   */
  className: _propTypes.default.string,

  /**
   * Custom Icon that will be rendered inside the ProgressRing. Will be overwritten by status icons.
   */
  customIcon: _propTypes.default.element,

  /**
   * Progress value (between min-max)
   */
  progress: _propTypes.default.number,

  /**
   * Progress min
   */
  min: _propTypes.default.number,

  /**
   * Progress max
   */
  max: _propTypes.default.number,

  /**
   * large size
   */
  size: _propTypes.default.oneOf(['large']),

  /**
   * Progress status
   */
  status: _propTypes.default.oneOf(['expired', 'warning', 'active-step']),

  /**
   * fill or drain the ring (fill means the colored portion of the ring increases clockwise)
   */
  variant: _propTypes.default.oneOf(['fill', 'drain'])
} : {};
var _default = ProgressRing;
exports.default = _default;