"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _utils = require("../../utils");

var _Icon = require("../Icon");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Cell = function Cell(props) {
  var children = props.children,
      className = props.className,
      resizable = props.resizable,
      resizableAssistiveText = props.resizableAssistiveText,
      scope = props.scope,
      sortable = props.sortable,
      sortDirection = props.sortDirection,
      sortAssistiveText = props.sortAssistiveText,
      title = props.title,
      truncate = props.truncate,
      variation = props.variation,
      rest = _objectWithoutProperties(props, ["children", "className", "resizable", "resizableAssistiveText", "scope", "sortable", "sortDirection", "sortAssistiveText", "title", "truncate", "variation"]);

  var getTitle = function getTitle() {
    var text = null;

    if (title) {
      text = title;
    } else if (typeof children === 'string') {
      text = children;
    } else if (_react.default.isValidElement(children) && typeof children.props.children === 'string') {
      text = children.props.children;
    }

    return text;
  };

  var inputId = (0, _utils.uniqueId)('resize-handle-');
  var cellTitle = getTitle();
  var isHeader = scope === 'col' || scope === 'row';
  var CellElement = isHeader ? 'th' : 'td';
  var cellScope = isHeader ? scope : null;

  var cellContent = function cellContent(key) {
    if ((!!resizable || !!sortable) && typeof children === 'string') {
      return _react.default.createElement("span", {
        key: key
      }, children);
    }

    return children;
  };

  var resizeHandle = function resizeHandle(key) {
    if (resizable) {
      return _react.default.createElement("div", {
        key: key,
        className: "slds-resizable"
      }, _react.default.createElement("label", {
        className: "slds-assistive-text",
        htmlFor: inputId
      }, resizableAssistiveText), _react.default.createElement("input", {
        className: "slds-resizable__input slds-assistive-text",
        type: "range",
        min: "20",
        max: "1000",
        id: inputId
      }), _react.default.createElement("span", {
        className: "slds-resizable__handle"
      }, _react.default.createElement("span", {
        className: "slds-resizable__divider"
      })));
    }

    return null;
  };

  var sortIcon = function sortIcon(key) {
    if (!!sortable && isHeader) {
      return _react.default.createElement("div", {
        key: key,
        className: "slds-icon_container",
        title: sortAssistiveText
      }, _react.default.createElement(_Icon.IconSVG, {
        className: "slds-is-sortable__icon slds-icon-text-default",
        icon: "arrowdown",
        size: "x-small",
        sprite: "utility"
      }));
    }

    return null;
  };

  var assistiveText = function assistiveText(key) {
    if (!!sortable && isHeader) {
      return _react.default.createElement("span", {
        key: key,
        className: "slds-assistive-text"
      }, cellTitle);
    }

    return null;
  };

  var wrapChildren = function wrapChildren(content) {
    if (isHeader) {
      return sortable ? _react.default.createElement("a", {
        className: "slds-th__action slds-text-link_reset"
      }, content) : _react.default.createElement("span", null, content);
    }

    return content;
  };

  var childArray = [];
  childArray.push(cellContent(1));
  childArray.push(resizeHandle(2));
  childArray.push(sortIcon(3));
  childArray.push(assistiveText(4));
  var variationClasses = Array.isArray(variation) ? variation.map(function (f) {
    return "slds-".concat(f);
  }) : "slds-".concat(variation);
  var sldsClasses = [{
    'slds-is-resizable': scope === 'col' && !!resizable
  }, {
    'slds-is-sortable': !!sortable
  }, {
    'slds-is-sorted_asc': !!sortable && sortDirection === 'asc'
  }, variationClasses, className];
  var wrappedChildren = wrapChildren(childArray);
  var wrapperClassName = (0, _classnames.default)({
    'slds-truncate': truncate
  });
  return _react.default.createElement(CellElement, _extends({}, rest, {
    className: (0, _classnames.default)(sldsClasses),
    scope: cellScope
  }), _react.default.createElement("div", {
    className: wrapperClassName,
    title: cellTitle
  }, wrappedChildren));
};

Cell.defaultProps = {
  children: null,
  className: null,
  resizable: false,
  resizableAssistiveText: 'Resize Cell',
  scope: null,
  sortable: false,
  sortAssistiveText: 'Sort Column',
  sortDirection: 'asc',
  title: null,
  truncate: true,
  variation: []
};
Cell.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * cell content
   */
  children: _propTypes.default.node,

  /**
   * class name
   */
  className: _propTypes.default.string,

  /**
   * makes the cell resizable
   */
  resizable: _propTypes.default.bool,

  /**
   * assistiveText for resize handler
   */
  resizableAssistiveText: _propTypes.default.string,

  /**
   * only `th` cells have a scope. Header cells have a col scope, and leading body cells can have a row scope
   */
  scope: _propTypes.default.oneOf(['col', 'row']),

  /**
   * renders a sortable cell
   */
  sortable: _propTypes.default.bool,

  /**
   * assistive text for the sort icon
   */
  sortAssistiveText: _propTypes.default.string,

  /**
   * sortDirection
   */
  sortDirection: _propTypes.default.oneOf(['asc', 'desc']),

  /**
   * overrides the cell's title attribute
   */
  title: _propTypes.default.string,

  /**
   * Whether the cell content should be truncated
   */
  truncate: _propTypes.default.bool,

  /*
   * Variation: string or array of strings. Variations: cell-wrap, cell-shrink
   */
  variation: _propTypes.default.oneOfType([_propTypes.default.oneOf(['cell-wrap', 'cell-shrink']), _propTypes.default.arrayOf(_propTypes.default.oneOf(['cell-wrap', 'cell-shrink']))])
} : {};
var _default = Cell;
exports.default = _default;