"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Badge = require("../Badge");

var _Icon = require("../Icon");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var VerticalNavigationItem = function VerticalNavigationItem(props) {
  var children = props.children,
      className = props.className,
      icon = props.icon,
      isActive = props.isActive,
      notification = props.notification,
      notificationLabel = props.notificationLabel,
      rest = _objectWithoutProperties(props, ["children", "className", "icon", "isActive", "notification", "notificationLabel"]);

  var containerClasses = ['slds-nav-vertical__item', {
    'slds-is-active': isActive
  }];
  var sldsClasses = ['slds-nav-vertical__action', className];

  var renderNotification = function renderNotification() {
    return _react.default.createElement(_Badge.Badge, {
      className: "slds-col_bump-left",
      title: notificationLabel || "".concat(notification)
    }, "".concat(notification));
  };

  var renderIcon = function renderIcon() {
    var iconName = icon.icon,
        sprite = icon.sprite,
        title = icon.title;
    var iconClasses = ['slds-icon_container', "slds-icon-".concat(sprite, "-").concat(iconName), 'slds-line-height_reset'];
    return _react.default.createElement("span", {
      className: (0, _classnames.default)(iconClasses),
      title: title
    }, _react.default.createElement(_Icon.IconSVG, {
      className: "slds-icon-text-default slds-m-right_x-small",
      icon: iconName,
      sprite: sprite,
      size: "x-small"
    }));
  };
  /* eslint-disable jsx-a11y/aria-props */


  return _react.default.createElement("li", {
    className: (0, _classnames.default)(containerClasses)
  }, _react.default.createElement("a", _extends({
    className: (0, _classnames.default)(sldsClasses),
    "aria-current": isActive ? 'page' : null
  }, rest), icon && renderIcon(), children, notification != null && renderNotification()));
};

VerticalNavigationItem.defaultProps = {
  className: null,
  icon: null,
  isActive: false,
  notification: null,
  notificationLabel: null
};
VerticalNavigationItem.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Child node, text for default behaviour
   */
  children: _propTypes.default.node.isRequired,

  /**
   * Classname to be applied to the contained linked element
   */
  className: _propTypes.default.string,

  /**
   * Icon that will be rendered to the left of children
   */
  icon: _propTypes.default.shape({
    icon: _propTypes.default.string,
    sprite: _propTypes.default.string,
    title: _propTypes.default.string
  }),

  /**
   * Sets active navigation state
   */
  isActive: _propTypes.default.bool,

  /**
   * String or number indicating new items
   */
  notification: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),

  /**
   * ARIA-description for the notification
   */
  notificationLabel: _propTypes.default.string
} : {};
var _default = VerticalNavigationItem;
exports.default = _default;