import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { THEMES, getThemeClass } from '../../utils';
import { IconButton, ButtonIcon } from '../Button';

var Alert = function Alert(props) {
  var children = props.children,
      className = props.className,
      icon = props.icon,
      title = props.title,
      toast = props.toast,
      theme = props.theme,
      onClickClose = props.onClickClose,
      rest = _objectWithoutProperties(props, ["children", "className", "icon", "title", "toast", "theme", "onClickClose"]);

  var sldsClasses = ['slds-notify', {
    'slds-notify_toast': toast
  }, {
    'slds-notify_alert slds-theme_alert-texture': !toast
  }, getThemeClass(theme), className];
  var iconEl;
  var iconContainerClasses;

  if (React.isValidElement(icon)) {
    iconEl = React.cloneElement(icon, {
      size: toast ? 'small' : 'x-small'
    });
    iconContainerClasses = ['slds-icon_container', {
      'slds-m-right_small slds-no-flex slds-align-top': toast
    }, {
      'slds-m-right_x-small': !toast
    }];
  }

  var alert = React.createElement("div", _extends({}, rest, {
    className: cx(sldsClasses),
    role: toast ? 'status' : 'alert'
  }), React.createElement("span", {
    className: "slds-assistive-text"
  }, title), iconEl && React.createElement("span", {
    className: cx(iconContainerClasses)
  }, iconEl), toast ? React.createElement("div", {
    className: "slds-notify__content"
  }, children) : children, onClickClose && React.createElement("div", {
    className: "slds-notify__close"
  }, React.createElement(IconButton, {
    flavor: "inverse",
    onClick: onClickClose,
    title: "Close"
  }, React.createElement(ButtonIcon, {
    sprite: "utility",
    icon: "close",
    size: toast ? 'large' : 'small'
  }))));
  return toast ? React.createElement("div", {
    className: "slds-notify_container slds-is-relative"
  }, alert) : alert;
};

Alert.defaultProps = {
  className: null,
  icon: null,
  toast: false,
  onClickClose: null,
  theme: 'info'
};
Alert.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * notification content
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
  * IconSVG element
  */
  icon: PropTypes.element,

  /**
   * notification title (will be rendered as assistiveText)
   */
  title: PropTypes.string.isRequired,

  /**
   * render the notification as a toast
   */
  toast: PropTypes.bool,

  /**
   * function to call when close button is clicked
   */
  onClickClose: PropTypes.func,

  /**
   * notification theme (warning, error, offline, info (default))
   */
  theme: PropTypes.oneOf(THEMES)
} : {};
export default Alert;