import "core-js/modules/es.symbol";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.values";
import "core-js/modules/web.dom-collections.for-each";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { get } from 'lodash-es';
import cx from 'classnames';
import { CHAT_ITEM_TYPES } from './utils';
import ChatListItem from './ChatListItem';
var DEFAULT_TRANSLATIONS = {
  at: 'at',
  resend: 'Resend',
  said: 'said'
};

var Chat = function Chat(_ref) {
  var className = _ref.className,
      isPastChat = _ref.isPastChat,
      items = _ref.items,
      translations = _ref.translations;
  var sectionClassNames = cx(['slds-chat', {
    'slds-chat_past': isPastChat
  }, className]);

  var mergedTranslation = _objectSpread({}, DEFAULT_TRANSLATIONS, {}, translations);

  return React.createElement("section", {
    role: "log",
    className: sectionClassNames
  }, React.createElement("ul", {
    className: "slds-chat-list"
  }, items.map(function (item, i) {
    var messageAuthor = item.author,
        id = item.id,
        type = item.type;
    var isConsecutive = false;
    var isFirstMessage = false;

    var _get = get(items, [i - 1], {}),
        prevAuthor = _get.author,
        prevIsStart = _get.isStart;

    var _get2 = get(items, [i + 1], {}),
        nextAuthor = _get2.author,
        nextType = _get2.type;

    if (!isPastChat && type === nextType && messageAuthor === nextAuthor) {
      isConsecutive = true;
    }

    isFirstMessage = prevIsStart || prevAuthor !== messageAuthor;
    return React.createElement(ChatListItem, _extends({
      isConsecutive: isConsecutive,
      isFirstMessage: isFirstMessage,
      isPastChat: isPastChat,
      key: "chat-list-item-".concat(id),
      translations: mergedTranslation
    }, item));
  })));
};

Chat.defaultProps = {
  className: null,
  isPastChat: false,
  translations: DEFAULT_TRANSLATIONS
};
Chat.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  isPastChat: PropTypes.bool,
  items: PropTypes.arrayOf(PropTypes.shape({
    author: PropTypes.string,
    attachment: PropTypes.shape({
      fileType: PropTypes.string.isRequired,
      isLink: PropTypes.bool,
      src: PropTypes.string,
      title: PropTypes.string.isRequired
    }),
    avatar: PropTypes.string,
    error: PropTypes.node,
    id: PropTypes.string.isRequired,
    message: PropTypes.node,
    meta: PropTypes.node,
    onResend: PropTypes.func,
    timestamp: PropTypes.string,
    type: PropTypes.oneOf(Object.values(CHAT_ITEM_TYPES))
  })).isRequired,
  translations: PropTypes.shape({
    at: PropTypes.string,
    resend: PropTypes.string,
    said: PropTypes.string
  })
} : {};
export default Chat;