import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.values";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ChatListItemMessage from './ChatListItemMessage';
import ChatListItemEvent from './ChatListItemEvent';
import ChatListItemBookend from './ChatListItemBookend';
import { CHAT_ITEM_TYPES } from './utils';

var ChatListItem = function ChatListItem(props) {
  var isPastChat = props.isPastChat,
      type = props.type;
  var isEnd = type === CHAT_ITEM_TYPES.EVENT_STOP;
  var isStart = type === CHAT_ITEM_TYPES.EVENT_START;
  var isBookend = isStart || isEnd;
  var isError = type === CHAT_ITEM_TYPES.EVENT_ERROR;
  var isEvent = type === CHAT_ITEM_TYPES.EVENT || isError;

  function getListItemCssClass() {
    if (isBookend) return 'bookend';
    if (isEvent) return 'event';
    if (type === CHAT_ITEM_TYPES.MESSAGE_OUTBOUND || type === CHAT_ITEM_TYPES.MESSAGE_DELIVERY_FAILURE || type === CHAT_ITEM_TYPES.MESSAGE_OUTBOUND_AGENT) return 'outbound';
    return 'inbound';
  }

  var classNamesItem = cx(['slds-chat-listitem', _defineProperty({}, "slds-chat-listitem_".concat(getListItemCssClass()), isBookend || !isPastChat)]);
  return React.createElement("li", {
    className: classNamesItem
  }, function () {
    if (isEvent) return React.createElement(ChatListItemEvent, _extends({}, props, {
      isError: isError
    }));
    if (isBookend) return React.createElement(ChatListItemBookend, _extends({}, props, {
      isEnd: isEnd
    }));
    return React.createElement(ChatListItemMessage, props);
  }());
};

ChatListItem.propTypes = process.env.NODE_ENV !== "production" ? {
  isPastChat: PropTypes.bool.isRequired,
  type: PropTypes.oneOf(Object.values(CHAT_ITEM_TYPES)).isRequired
} : {};
export default ChatListItem;