import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import { PropTypes } from 'prop-types';
import cx from 'classnames';
import { CHAT_ITEM_TYPES } from '../utils';
import { MessageMeta } from './MessageMeta';
import { MessageFile } from './MessageFile';
import { MessageStatus } from './MessageStatus';
/* eslint-disable react/jsx-one-expression-per-line */

export var MessageContent = function MessageContent(_ref) {
  var attachment = _ref.attachment,
      author = _ref.author,
      error = _ref.error,
      isConsecutive = _ref.isConsecutive,
      isPastChat = _ref.isPastChat,
      message = _ref.message,
      meta = _ref.meta,
      type = _ref.type,
      rest = _objectWithoutProperties(_ref, ["attachment", "author", "error", "isConsecutive", "isPastChat", "message", "meta", "type"]);

  var hasAttachment = !!attachment;
  var isLink = hasAttachment && attachment.isLink;
  var isImage = hasAttachment && attachment.fileType === 'image';
  var isCoAuthor = type === CHAT_ITEM_TYPES.MESSAGE_OUTBOUND_AGENT;
  var isDeliveryFailure = type === CHAT_ITEM_TYPES.MESSAGE_DELIVERY_FAILURE;
  var isTyping = type === CHAT_ITEM_TYPES.MESSAGE_TYPING;
  var isUnsupportedType = type === CHAT_ITEM_TYPES.MESSAGE_UNSUPPORTED_TYPE;

  function getMessageSourceCssClass() {
    if (type === CHAT_ITEM_TYPES.MESSAGE_INBOUND || isUnsupportedType || isTyping) return 'inbound';
    if (isCoAuthor) return 'outbound-agent';
    return 'outbound';
  }

  var classNamesMessageText = cx([{
    'slds-chat-message__text': isLink || !hasAttachment
  }, _defineProperty({}, "slds-chat-message__text_".concat(getMessageSourceCssClass()), !isPastChat && (isLink || !hasAttachment)), {
    'slds-chat-message__text_unsupported-type': isUnsupportedType
  }, {
    'slds-chat-message__text_delivery-failure': isDeliveryFailure
  }, {
    'slds-chat-message__text_sneak-peek': isTyping && message
  }, {
    'slds-chat-message__image': !isLink && isImage
  }, _defineProperty({}, "slds-chat-message__image_".concat(getMessageSourceCssClass()), !isLink && isImage), {
    'slds-chat-message__file': hasAttachment && !isLink && !isImage
  }, _defineProperty({}, "slds-chat-message__file_".concat(getMessageSourceCssClass()), hasAttachment && !isLink && !isImage)]);

  if (isTyping) {
    return React.createElement("div", {
      className: classNamesMessageText
    }, React.createElement("span", {
      className: "slds-icon-typing slds-is-animated",
      title: meta
    }, React.createElement("span", {
      className: "slds-icon-typing__dot"
    }), React.createElement("span", {
      className: "slds-icon-typing__dot"
    }), React.createElement("span", {
      className: "slds-icon-typing__dot"
    }), React.createElement("span", {
      className: "slds-assistive-text"
    }, meta)), React.createElement("span", {
      "aria-hidden": "true"
    }, message));
  }

  var messageMeta = React.createElement(MessageMeta, _extends({
    author: author,
    isConsecutive: isConsecutive,
    isDeliveryFailure: isDeliveryFailure,
    isPastChat: isPastChat,
    meta: meta
  }, rest));

  var renderMessageStatus = function renderMessageStatus(msg) {
    return React.createElement(MessageStatus, {
      message: msg,
      isDeliveryFailure: isDeliveryFailure,
      isUnsupportedType: isUnsupportedType
    });
  };

  return React.createElement(React.Fragment, null, isPastChat && messageMeta, React.createElement("div", {
    className: classNamesMessageText
  }, hasAttachment && React.createElement(MessageFile, attachment), isUnsupportedType ? renderMessageStatus(message) : React.createElement("span", null, message), isDeliveryFailure && React.createElement("div", {
    className: "slds-chat-message__text_delivery-failure-reason",
    role: "alert"
  }, renderMessageStatus(error))), !isPastChat && messageMeta);
};
/* eslint-enable react/jsx-one-expression-per-line */

MessageContent.defaultProps = {
  attachment: null,
  error: null,
  message: null,
  meta: null
};
MessageContent.propTypes = process.env.NODE_ENV !== "production" ? {
  attachment: PropTypes.object,
  author: PropTypes.string.isRequired,
  error: PropTypes.string,
  isConsecutive: PropTypes.bool.isRequired,
  isPastChat: PropTypes.bool.isRequired,
  message: PropTypes.node,
  meta: PropTypes.node,
  type: PropTypes.string.isRequired
} : {};