import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.slice";
import "core-js/modules/es.regexp.exec";
import "core-js/modules/es.string.search";
import "core-js/modules/es.string.split";
import "core-js/modules/web.dom-collections.for-each";
import React from 'react';
export var scrollDropdown = function scrollDropdown(parentNode, childNode) {
  var viewPortTop = parentNode.scrollTop;
  var viewPortBottom = viewPortTop + parentNode.offsetHeight;
  var selectedTop = childNode.offsetTop;
  var selectedBottom = selectedTop + childNode.offsetHeight;
  /* eslint-disable no-param-reassign */

  if (selectedBottom > viewPortBottom) {
    parentNode.scrollTop += selectedBottom - viewPortBottom;
  } else if (selectedTop < viewPortTop) {
    parentNode.scrollTop += selectedTop - viewPortTop;
  }
  /* eslint-enable no-param-reassign */

};
export var getNextIndex = function getNextIndex(items, prevIndex) {
  var direction = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'desc';
  if (prevIndex == null) return getNextIndex(items, direction === 'desc' ? -1 : 0, direction);
  var len = items.length;

  var getIndexInBounds = function getIndexInBounds(nextIndex) {
    return (nextIndex % len + len) % len;
  };

  var nextIndex = getIndexInBounds(direction === 'desc' ? prevIndex + 1 : prevIndex - 1);
  var nextItem = items[nextIndex];
  return nextItem.isHeader ? getNextIndex(items, nextIndex, direction) : nextIndex;
};
export var preventDefault = function preventDefault(evt) {
  return evt.preventDefault();
};

var makeHighlighter = function makeHighlighter(highlighter) {
  return function () {
    var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var search = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    var searchLen = search.length;
    if (searchLen === 0) return str;
    var splitLabel = str.toLowerCase().split(search.toLowerCase());
    var splitLen = splitLabel.length;
    if (splitLen < 2) return str;
    var startIndex = 0;
    var result = [];
    splitLabel.forEach(function (strPos, i) {
      var len = strPos.length;
      var origIndex = startIndex + len;
      var origStr = str.slice(startIndex, origIndex);
      startIndex = origIndex;
      var highlightEl = null;
      var highlightStr = '';

      if (i !== splitLen - 1) {
        var searchIndex = startIndex + searchLen;
        highlightStr = str.slice(startIndex, searchIndex);
        highlightEl = highlighter(highlightStr);
        startIndex = searchIndex;
      }

      result.push(React.createElement(React.Fragment, {
        key: "".concat(origStr).concat(highlightStr)
      }, origStr, highlightEl));
    });
    return result;
  };
};

export var defaultHighlighter = makeHighlighter(function (str) {
  return React.createElement("mark", null, str);
});
export var byItemId = function byItemId(value) {
  return function (_ref) {
    var id = _ref.id;
    return id === value;
  };
};
export var isSelectionReplace = function isSelectionReplace(opts) {
  var isMultiSelect = opts.isMultiSelect,
      selectedItems = opts.selectedItems;
  return !isMultiSelect && selectedItems.length > 0;
};
export var makeInputAddHandler = function makeInputAddHandler(originalHandler, opts) {
  var isOpen = opts.isOpen,
      keyboardSelection = opts.keyboardSelection,
      onToggle = opts.onToggle,
      onSelect = opts.rawOnSelect,
      search = opts.search;
  return function (evt) {
    var key = evt.key;
    var isKeyboardAdd = isOpen && search !== '' && !keyboardSelection && key === 'Enter';

    if (isKeyboardAdd) {
      onSelect(search, {
        isAdd: true,
        isReplace: isSelectionReplace(opts),
        isRemove: false
      });
      onToggle(false);
      return true;
    }

    return originalHandler(evt);
  };
};