import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import FileActions from './FileActions';
import FileCaption from './FileCaption';
import FileExternalIcon from './FileExternalIcon';
import FileMedia from './FileMedia';
var RATIOS = process.env.NODE_ENV !== "production" ? ['1-by-1', '4-by-3', '16-by-9'] : {};

var File = function File(props) {
  var actions = props.actions,
      className = props.className,
      externalIcon = props.externalIcon,
      fileType = props.fileType,
      hideTitle = props.hideTitle,
      image = props.image,
      isLoading = props.isLoading,
      ratio = props.ratio,
      title = props.title,
      rest = _objectWithoutProperties(props, ["actions", "className", "externalIcon", "fileType", "hideTitle", "image", "isLoading", "ratio", "title"]);

  var sldsClasses = ['slds-file', 'slds-file_card', {
    'slds-has-title': !hideTitle
  }, {
    'slds-file_loading': isLoading
  }];
  var mediaClasses = ['slds-file__crop', _defineProperty({}, "slds-file__crop_".concat(ratio), ratio), className];
  return React.createElement("div", {
    className: cx(sldsClasses)
  }, React.createElement("figure", null, React.createElement("a", _extends({}, rest, {
    className: cx(mediaClasses)
  }), React.createElement(FileMedia, {
    fileType: fileType,
    image: image,
    isLoading: isLoading,
    title: title
  })), !hideTitle && React.createElement(FileCaption, {
    fileType: fileType,
    hasActions: !!actions,
    title: title
  }), actions && React.createElement(FileActions, {
    hideTitle: hideTitle
  }, actions), externalIcon && React.createElement(FileExternalIcon, {
    externalIcon: externalIcon
  })));
};

File.defaultProps = {
  actions: null,
  className: null,
  externalIcon: null,
  fileType: 'image',
  image: null,
  isLoading: false,
  ratio: null,
  hideTitle: false
};
File.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * ButtonGroup with actions
   */
  actions: PropTypes.element,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * Renders an externalIcon for images from external services
   */
  externalIcon: PropTypes.shape({
    icon: PropTypes.string,
    sprite: PropTypes.string,
    title: PropTypes.string
  }),

  /**
   * fileType corresponding to SF doctype icon
   */
  fileType: PropTypes.string,

  /**
   * Determines if the title is shown
   */
  hideTitle: PropTypes.bool,

  /**
   * Image with src & alt
   */
  image: PropTypes.shape({
    alt: PropTypes.string,
    src: PropTypes.string
  }),

  /**
   * Indicate a loading image
   */
  isLoading: PropTypes.bool,

  /**
   * Optional ratio:   '1-by-1', '4-by-3', '16-by-9'
   */
  ratio: PropTypes.oneOf(RATIOS),

  /**
   * Image title
   */
  title: PropTypes.string.isRequired
} : {};
export default File;