import "core-js/modules/es.array.concat";
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Dropzone from 'react-dropzone';
import { FormElement, FormElementControl, FormElementError } from '../Form';
import { Button } from '../Button';

var preventDefault = function preventDefault(e) {
  return e.preventDefault();
};

var FileSelector = function FileSelector(_ref) {
  var accept = _ref.accept,
      buttonText = _ref.buttonText,
      id = _ref.id,
      error = _ref.error,
      fatalError = _ref.fatalError,
      label = _ref.label,
      minSize = _ref.minSize,
      maxSize = _ref.maxSize,
      multiple = _ref.multiple,
      onDragEnter = _ref.onDragEnter,
      onDragLeave = _ref.onDragLeave,
      onDrop = _ref.onDrop,
      selectorText = _ref.selectorText,
      selectorType = _ref.selectorType;
  var errorStr = fatalError || error;
  var fileSelectorClasses = ['slds-file-selector', "slds-file-selector_".concat(selectorType)];
  var primaryLabelId = "".concat(id, "-primary-label");
  var secondaryLabelId = "".concat(id, "-secondary-label");
  return React.createElement(FormElement, {
    error: errorStr
  }, React.createElement("span", {
    className: "slds-form-element__label",
    id: primaryLabelId
  }, label), React.createElement(FormElementControl, null, React.createElement("div", {
    className: cx(fileSelectorClasses)
  }, React.createElement(Dropzone, {
    accept: accept,
    disabled: !!fatalError,
    minSize: minSize,
    maxSize: maxSize,
    multiple: multiple,
    onDrop: onDrop,
    onDragEnter: onDragEnter,
    onDragLeave: onDragLeave
  }, function (_ref2) {
    var getRootProps = _ref2.getRootProps,
        getInputProps = _ref2.getInputProps,
        isDragActive = _ref2.isDragActive;
    return React.createElement("div", getRootProps({
      className: cx(['slds-file-selector__dropzone', {
        'slds-has-drag-over': isDragActive && !fatalError
      }])
    }), React.createElement("input", getInputProps({
      'aria-labelledby': "".concat(primaryLabelId, " ").concat(secondaryLabelId),
      className: 'slds-file-selector__input slds-assistive-text',
      disabled: fatalError,
      id: id
    })), React.createElement("label", {
      className: "slds-file-selector__body",
      htmlFor: id // Fixes dialog not working due to default `label<>input` event handling (Safari,Chrome)
      ,
      onClick: preventDefault,
      id: secondaryLabelId
    }, React.createElement(Button, {
      buttonEl: "span",
      className: "slds-file-selector__button",
      flavor: "neutral",
      icon: "upload",
      sprite: "utility",
      title: buttonText
    }), React.createElement("span", {
      className: "slds-file-selector__text slds-medium-show"
    }, selectorText)));
  }))), React.createElement(FormElementError, {
    error: errorStr,
    id: id
  }));
};

FileSelector.defaultProps = {
  accept: null,
  error: null,
  fatalError: null,
  minSize: 0,
  maxSize: null,
  multiple: false,
  onDragEnter: null,
  onDragLeave: null,
  selectorType: 'files'
};
FileSelector.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Maps to the HTML5 `accept` attribute. Used to narrow down allowed file types
   */
  accept: PropTypes.string,

  /**
   * Button title
   */
  buttonText: PropTypes.string.isRequired,

  /**
   * Error displayed below form. This should be used for informational messages as it does not disable the dropzone
   */
  error: PropTypes.string,

  /**
   * Takes precedence over `error` and _will_ disable the dropzone
   */
  fatalError: PropTypes.string,

  /**
   * Id of this file selector
   */
  id: PropTypes.string.isRequired,

  /**
   * Top-level label
   */
  label: PropTypes.string.isRequired,

  /**
   * Minimum file size (in bytes)
   */
  minSize: PropTypes.number,

  /**
   * Maximum file size (in bytes)
   */
  maxSize: PropTypes.number,

  /**
   * Maps to the HTML5 `multiple` attribute
   */
  multiple: PropTypes.bool,

  /**
   * `onDragEnter` passed to `Dropzone`. Called with:
   *   - `event`
   */
  onDragEnter: PropTypes.func,

  /**
   * `onDragLeave` passed to `Dropzone`. Called with:
   *   - `event`
   */
  onDragLeave: PropTypes.func,

  /**
   * `onDrop` passed to `Dropzone`. Called with:
   *   - `acceptedFiles`
   *   - `rejectedFiles`
   *   - `event`
   */
  onDrop: PropTypes.func.isRequired,

  /**
   * Addl. text rendered next to the button
   */
  selectorText: PropTypes.string.isRequired,

  /**
   * Toggles display style
   */
  selectorType: PropTypes.oneOf(['files', 'images'])
} : {};
export default FileSelector;