import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { getUniqueHash } from '../../utils';

var CheckboxRaw = function CheckboxRaw(props) {
  var checked = props.checked,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      onChange = props.onChange,
      required = props.required,
      wrapperClassName = props.wrapperClassName,
      rest = _objectWithoutProperties(props, ["checked", "className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "onChange", "required", "wrapperClassName"]);

  var renderCheckbox = function renderCheckbox() {
    return React.createElement("input", _extends({
      "aria-describedby": error && !hideErrorMessage ? getUniqueHash(error, id) : null
    }, rest, {
      checked: checked,
      className: className,
      disabled: disabled,
      id: id,
      name: "options",
      onChange: onChange,
      type: "checkbox"
    }));
  };

  var labelClasses = ['slds-form-element__label', {
    'slds-assistive-text': hideLabel
  }];

  var renderLabel = function renderLabel() {
    return React.createElement("label", {
      className: "slds-checkbox__label",
      htmlFor: id
    }, React.createElement("span", {
      className: "slds-checkbox_faux"
    }), React.createElement("span", {
      className: cx(labelClasses)
    }, label));
  };

  var renderRequired = function renderRequired() {
    if (!required) {
      return null;
    }

    return React.createElement("abbr", {
      className: "slds-required",
      title: "required"
    }, "*");
  };

  var spanClass = cx(['slds-checkbox', wrapperClassName]);
  return React.createElement("span", {
    className: spanClass
  }, renderRequired(), renderCheckbox(), renderLabel());
};

CheckboxRaw.defaultProps = {
  checked: null,
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: function onChange() {},
  required: false,
  wrapperClassName: null
};
CheckboxRaw.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * checks the checkbox
   */
  checked: PropTypes.bool,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
  * adds disabled attribute
   */
  disabled: PropTypes.bool,

  /**
  * renders an error for the checkbox
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * id of the checkbox
   */
  id: PropTypes.string.isRequired,

  /**
   * label
   */
  label: PropTypes.node.isRequired,

  /**
   * onChange handler
   */
  onChange: PropTypes.func,

  /**
   * adds required attribute to the checkbox
   */
  required: PropTypes.bool,

  /**
   * sets class name for wrapper <span/> element
   */
  wrapperClassName: PropTypes.string
} : {};
export default CheckboxRaw;