import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var FormElementLabel = function FormElementLabel(props) {
  var className = props.className,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      legend = props.legend,
      readOnly = props.readOnly,
      required = props.required,
      rest = _objectWithoutProperties(props, ["className", "hideLabel", "id", "label", "legend", "readOnly", "required"]);

  var renderRequired = function renderRequired() {
    if (required) {
      return React.createElement("abbr", {
        className: "slds-required",
        title: "required"
      }, "*");
    }

    return null;
  };

  var Tag = 'label';

  if (readOnly) {
    Tag = 'span';
  } else if (legend) {
    Tag = 'legend';
  }

  var sldsClasses = ['slds-form-element__label', {
    'slds-form-element__legend': !!legend
  }, {
    'slds-assistive-text': hideLabel
  }, className];
  return React.createElement(Tag, _extends({}, rest, {
    className: cx(sldsClasses),
    htmlFor: readOnly || legend ? null : id
  }), renderRequired(), label);
};

FormElementLabel.defaultProps = {
  className: null,
  hideLabel: false,
  legend: false,
  readOnly: false,
  required: false
};
FormElementLabel.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * id of the corresponding input tag element
   */
  id: PropTypes.string.isRequired,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * label content
   */
  label: PropTypes.node.isRequired,

  /**
   * Renders as a html5 legend
   */
  legend: PropTypes.bool,

  /**
   * renders the label as a span-tag instead of a label-tag
   */
  readOnly: PropTypes.bool,

  /**
   * label for required inputs
   */
  required: PropTypes.bool
} : {};
export default FormElementLabel;