import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import FormElementLabel from './FormElementLabel';
import InputRaw from './InputRaw';
var Input = React.forwardRef(function (props, ref) {
  var error = props.error,
      errorIcon = props.errorIcon,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      iconLeft = props.iconLeft,
      iconRight = props.iconRight,
      id = props.id,
      isStatic = props.isStatic,
      label = props.label,
      placeholder = props.placeholder,
      readOnly = props.readOnly,
      required = props.required,
      showSpinner = props.showSpinner,
      value = props.value,
      rest = _objectWithoutProperties(props, ["error", "errorIcon", "hideErrorMessage", "hideLabel", "iconLeft", "iconRight", "id", "isStatic", "label", "placeholder", "readOnly", "required", "showSpinner", "value"]);

  var hasIconLeft = !!iconLeft || error && errorIcon;
  var hasIconRight = !!iconRight || !!showSpinner;
  return React.createElement(FormElement, {
    isStatic: isStatic,
    required: required,
    error: error
  }, React.createElement(FormElementLabel, {
    hideLabel: hideLabel,
    id: id,
    label: label,
    readOnly: isStatic,
    required: required
  }), React.createElement(FormElementControl, {
    hasIconLeft: hasIconLeft,
    hasIconRight: hasIconRight
  }, !isStatic ? React.createElement(InputRaw, _extends({
    error: error,
    errorIcon: errorIcon,
    hideErrorMessage: hideErrorMessage,
    iconLeft: iconLeft,
    iconRight: iconRight,
    id: id,
    label: label,
    placeholder: placeholder,
    readOnly: readOnly,
    ref: ref,
    required: required,
    showSpinner: showSpinner,
    value: value
  }, rest)) : React.createElement("div", {
    className: "slds-form-element__static"
  }, value)), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
});
Input.displayName = 'Input';
Input.defaultProps = {
  bare: false,
  className: null,
  disabled: false,
  error: null,
  errorIcon: false,
  hideErrorMessage: false,
  hideLabel: false,
  iconLeft: null,
  iconRight: null,
  iconRightOnClick: function iconRightOnClick() {},
  label: null,
  onChange: function onChange() {},
  onFocus: function onFocus() {},
  onKeyPress: function onKeyPress() {},
  placeholder: null,
  readOnly: null,
  role: null,
  required: false,
  showSpinner: false,
  type: 'text',
  value: undefined
};
Input.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * renders a bare input
   */
  bare: PropTypes.bool,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * adds disabled attribute to the input field
   */
  disabled: PropTypes.bool,

  /**
   * renders an error for the input. shows an error messsage if error is a string,
   * just marks the input if its a boolean.
   */
  error: PropTypes.string,

  /**
   * renders an additional error icon if an error is set
   */
  errorIcon: PropTypes.bool,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * icon rendered on the left side of the input (from utility sprite)
   */
  iconLeft: PropTypes.string,

  /**
   * icon rendered on the right side of the input (from utility sprite)
   */
  iconRight: PropTypes.string,

  /**
   * onClick handler for the right icon
   */
  iconRightOnClick: PropTypes.func,

  /**
   * id of the input field
   */
  id: PropTypes.string.isRequired,

  /**
   * Renders in a static, "view" mode
   */
  isStatic: PropTypes.bool,

  /**
   * label for the input
   */
  label: PropTypes.node,

  /**
   * onChange handler for input
   */
  onChange: PropTypes.func,

  /**
   * onFocus handler for input
   */
  onFocus: PropTypes.func,

  /**
   * onKeyPress handler
   */
  onKeyPress: PropTypes.func,

  /**
   * placeholder for the input
   */
  placeholder: PropTypes.string,

  /**
   * Renders a read-only input element
   */
  readOnly: PropTypes.bool,

  /**
   * adds required attribute to input and label
   */
  required: PropTypes.bool,

  /**
   * role of the input field
   */
  role: PropTypes.string,

  /**
   * whether to show a spinner element inside the field, on the right end
   */
  showSpinner: PropTypes.bool,

  /**
   * input type. all HTML5 types are allowed, defaults to "text"
   * text, password, datetime, datetime-local, date, month, time, week, number, email, url, search, tel, and color
   */
  type: PropTypes.string,

  /**
   * value of the input field
   */
  value: PropTypes.string
} : {};
export default Input;