import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { Fragment } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { omit } from 'lodash-es';
import { getUniqueHash } from '../../utils';
import { IconButton } from '../Button';
import { IconSVG } from '../Icon';
import { Spinner } from '../Spinner';
var InputRaw = React.forwardRef(function (props, ref) {
  var bare = props.bare,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      errorIcon = props.errorIcon,
      hideErrorMessage = props.hideErrorMessage,
      iconLeft = props.iconLeft,
      iconRight = props.iconRight,
      iconRightOnClick = props.iconRightOnClick,
      id = props.id,
      onChange = props.onChange,
      onFocus = props.onFocus,
      onKeyPress = props.onKeyPress,
      placeholder = props.placeholder,
      required = props.required,
      role = props.role,
      showSpinner = props.showSpinner,
      type = props.type,
      value = props.value,
      rest = _objectWithoutProperties(props, ["bare", "className", "disabled", "error", "errorIcon", "hideErrorMessage", "iconLeft", "iconRight", "iconRightOnClick", "id", "onChange", "onFocus", "onKeyPress", "placeholder", "required", "role", "showSpinner", "type", "value"]);

  var renderIconLeft = function renderIconLeft() {
    if (React.isValidElement(iconLeft)) return iconLeft;
    var iconName = error && errorIcon ? 'warning' : iconLeft;

    if (iconName) {
      var iconClasses = ['slds-icon', 'slds-input__icon', 'slds-input__icon_left', 'slds-icon-text-default'];
      return React.createElement(IconSVG, {
        className: cx(iconClasses),
        icon: iconName,
        sprite: "utility"
      });
    }

    return null;
  };

  var renderIconRight = function renderIconRight() {
    if (iconRight && iconRightOnClick) {
      var iconClasses = ['slds-input__icon', 'slds-input__icon_right'];
      return React.createElement(IconButton, {
        icon: iconRight,
        sprite: "utility",
        className: cx(iconClasses),
        onClick: iconRightOnClick
      });
    }

    if (iconRight) {
      var _iconClasses = ['slds-icon-text-default', 'slds-icon', 'slds-input__icon', 'slds-input__icon_right'];
      return React.createElement(IconSVG, {
        className: cx(_iconClasses),
        sprite: "utility",
        icon: iconRight
      });
    }

    return null;
  };

  var sldsClasses = [bare ? 'slds-input_bare' : 'slds-input', className];
  return React.createElement(Fragment, null, renderIconLeft(), React.createElement("input", _extends({}, omit(rest, ['label']), {
    "aria-describedby": error && !hideErrorMessage ? getUniqueHash(error, id) : null,
    className: cx(sldsClasses),
    disabled: disabled,
    id: id,
    onChange: onChange,
    onFocus: onFocus,
    onKeyPress: onKeyPress,
    placeholder: placeholder,
    ref: ref,
    required: required,
    role: role,
    type: type,
    value: value
  })), showSpinner ? React.createElement("div", {
    className: "slds-input__icon-group slds-input__icon-group_right"
  }, React.createElement(Spinner, {
    flavor: "brand",
    className: "slds-input__spinner slds-m-right_xx-small",
    size: "x-small"
  }), renderIconRight()) : renderIconRight());
});
InputRaw.displayName = 'InputRaw';
InputRaw.defaultProps = {
  bare: false,
  className: null,
  disabled: false,
  error: null,
  errorIcon: false,
  hideErrorMessage: false,
  iconLeft: null,
  iconRight: null,
  iconRightOnClick: null,
  label: null,
  onChange: null,
  onFocus: null,
  onKeyPress: null,
  placeholder: null,
  role: null,
  required: false,
  showSpinner: false,
  type: 'text',
  value: undefined
};
InputRaw.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * renders a bare input
   */
  bare: PropTypes.bool,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * adds disabled attribute to the input field
   */
  disabled: PropTypes.bool,

  /**
   * renders an error for the input
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * renders an additional error icon if an error is set
   */
  errorIcon: PropTypes.bool,

  /**
   * icon rendered on the left side of the input (from utility sprite)
   */
  iconLeft: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /**
   * icon rendered on the right side of the input (from utility sprite)
   */
  iconRight: PropTypes.string,

  /**
   * onClick handler for the right icon
   */
  iconRightOnClick: PropTypes.func,

  /**
   * id of the input field
   */
  id: PropTypes.string.isRequired,

  /**
   * label for the input
   */
  label: PropTypes.node,

  /**
   * onChange handler for input
   */
  onChange: PropTypes.func,

  /**
   * onFocus handler for input
   */
  onFocus: PropTypes.func,

  /**
   * onKeyPress handler
   */
  onKeyPress: PropTypes.func,

  /**
   * placeholder for the input
   */
  placeholder: PropTypes.string,

  /**
   * adds required attribute to input and label
   */
  required: PropTypes.bool,

  /**
   * role of the input field
   */
  role: PropTypes.string,

  /**
   * whether to show a spinner element inside the field, on the right end
   */
  showSpinner: PropTypes.bool,

  /**
   * input type. all HTML5 types are allowed, defaults to "text"
   * text, password, datetime, datetime-local, date, month, time, week, number, email, url, search, tel, and color
   */
  type: PropTypes.string,

  /**
   * value of the input field
   */
  value: PropTypes.string
} : {};
export default InputRaw;