import React from 'react';
import PropTypes from 'prop-types';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import RadioRaw from './RadioRaw';

var Radio = function Radio(props) {
  var error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      id = props.id,
      required = props.required;
  return React.createElement(FormElement, {
    required: required,
    error: error
  }, React.createElement(FormElementControl, null, React.createElement(RadioRaw, props)), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
};

Radio.defaultProps = {
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  required: false
};
Radio.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * renders an error for the radio
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * id of the radio
   */
  id: PropTypes.string.isRequired,

  /**
   * adds required attribute to the radio
   */
  required: PropTypes.bool
} : {};
export default Radio;