import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import FormElementLabel from './FormElementLabel';
import { getUniqueHash } from '../../utils';

var RadioGroup = function RadioGroup(props) {
  var children = props.children,
      className = props.className,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      id = props.id,
      label = props.label,
      onChange = props.onChange,
      required = props.required,
      rest = _objectWithoutProperties(props, ["children", "className", "error", "hideErrorMessage", "id", "label", "onChange", "required"]);

  var wrapChildrenWithError = function wrapChildrenWithError() {
    if (!error || hideErrorMessage) {
      return children;
    }

    return React.Children.map(children, function (child) {
      return React.cloneElement(child, {
        'aria-describedby': getUniqueHash(error, id)
      });
    });
  };

  return React.createElement(FormElement, _extends({}, rest, {
    className: className,
    error: error,
    fieldset: true,
    id: id,
    onChange: onChange,
    required: required
  }), React.createElement(FormElementLabel, {
    legend: true,
    required: required,
    label: label,
    id: id
  }), React.createElement(FormElementControl, null, wrapChildrenWithError()), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
};

RadioGroup.defaultProps = {
  className: null,
  error: null,
  hideErrorMessage: false,
  onChange: function onChange() {},
  required: false
};
RadioGroup.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * the radio buttons to render
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * renders an error for the fieldset
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * id of the fieldset
   */
  id: PropTypes.string.isRequired,

  /**
   * label
   */
  label: PropTypes.node.isRequired,

  /**
   * onchange handler
   */
  onChange: PropTypes.func,

  /**
   * adds required attribute to the fieldset
   */
  required: PropTypes.bool
} : {};
export default RadioGroup;