import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { getUniqueHash } from '../../utils';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import FormElementLabel from './FormElementLabel';

var Select = function Select(props) {
  var children = props.children,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      multiple = props.multiple,
      onChange = props.onChange,
      required = props.required,
      rest = _objectWithoutProperties(props, ["children", "className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "multiple", "onChange", "required"]);

  var sldsClasses = ['slds-select', className];

  var renderSelect = function renderSelect() {
    var select = React.createElement("select", _extends({}, rest, {
      id: id,
      className: cx(sldsClasses),
      onChange: onChange,
      multiple: multiple,
      required: required,
      disabled: disabled,
      "aria-describedby": error && !hideErrorMessage ? getUniqueHash(error, id) : null
    }), children);

    if (multiple) {
      return select;
    }

    return React.createElement("div", {
      className: "slds-select_container"
    }, select);
  };

  return React.createElement(FormElement, {
    required: required,
    error: error
  }, React.createElement(FormElementLabel, {
    label: label,
    id: id,
    hideLabel: hideLabel,
    required: required
  }), React.createElement(FormElementControl, null, renderSelect()), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
};

Select.defaultProps = {
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  multiple: false,
  onChange: function onChange() {},
  required: false
};
Select.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * options & optgroups of the select
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * adds disabled attribute to the select
   */
  disabled: PropTypes.bool,

  /**
  * renders an error for the select
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * id of the select
   */
  id: PropTypes.string.isRequired,

  /**
   * label for the select
   */
  label: PropTypes.node.isRequired,

  /**
   * adds the multiple attribute to the select
   */
  multiple: PropTypes.bool,

  /**
   * onChange handler for the select
   */
  onChange: PropTypes.func,

  /**
   * adds required attribute to the select field and label
   */
  required: PropTypes.bool
} : {};
export default Select;