import "core-js/modules/es.array.concat";

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import FormElementLabel from './FormElementLabel';

var renderLabel = function renderLabel(label, min, max) {
  return React.createElement("span", {
    className: "slds-slider-label"
  }, React.createElement("span", {
    className: "slds-slider-label__label"
  }, label), React.createElement("span", {
    className: "slds-slider-label__range"
  }, "".concat(min, " - ").concat(max)));
};

var renderControl = function renderControl(onChange, id, value, min, max, step, size, disabled, vertical) {
  var baseClass = 'slds-slider';
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_vertical"), vertical), _defineProperty({}, "slds-size_".concat(size), !!size && !vertical)];
  return React.createElement("div", {
    className: cx(sldsClasses)
  }, React.createElement("input", {
    className: "slds-slider__range",
    type: "range",
    id: id,
    value: value,
    min: min,
    max: max,
    step: step,
    disabled: disabled,
    onChange: onChange
  }), React.createElement("span", {
    className: "slds-slider__value",
    "aria-hidden": "true"
  }, value));
};

var Slider = function Slider(props) {
  var label = props.label,
      value = props.value,
      onChange = props.onChange,
      min = props.min,
      max = props.max,
      step = props.step,
      id = props.id,
      size = props.size,
      disabled = props.disabled,
      vertical = props.vertical,
      error = props.error,
      hideLabel = props.hideLabel,
      hideErrorMessage = props.hideErrorMessage,
      className = props.className;
  return React.createElement(FormElement, {
    error: error,
    className: className
  }, React.createElement(FormElementLabel, {
    label: renderLabel(label, min, max),
    id: id,
    hideLabel: hideLabel
  }), React.createElement(FormElementControl, null, renderControl(onChange, id, value, min, max, step, size, disabled, vertical)), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
};

Slider.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * id of the slider
   */
  id: PropTypes.string.isRequired,

  /**
   * current value of the slider
   */
  value: PropTypes.number.isRequired,

  /**
   * minimum value
   */
  min: PropTypes.number,

  /**
   * maximum value
   */
  max: PropTypes.number,

  /**
   * step value
   */
  step: PropTypes.number,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * adds disabled attribute to the slider
   */
  disabled: PropTypes.bool,

  /**
   * render slider vertically
   */
  vertical: PropTypes.bool,

  /**
  * renders an error for the slider
   */
  error: PropTypes.string,

  /**
   * hides the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * label for the select
   */
  label: PropTypes.node,

  /**
   * onChange handler for the slider
   */
  onChange: PropTypes.func,

  /**
   * slider sizes: x-small, small, medium, large
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large'])
} : {};
Slider.defaultProps = {
  label: null,
  min: 0,
  max: 100,
  step: null,
  size: null,
  vertical: false,
  className: null,
  disabled: false,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: Function.prototype
};
export default Slider;