import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { getUniqueHash } from '../../utils';
import FormElement from './FormElement';
import FormElementControl from './FormElementControl';
import FormElementError from './FormElementError';
import FormElementLabel from './FormElementLabel';

var Textarea = function Textarea(props) {
  var className = props.className,
      disabled = props.disabled,
      error = props.error,
      hideErrorMessage = props.hideErrorMessage,
      hideLabel = props.hideLabel,
      id = props.id,
      label = props.label,
      onChange = props.onChange,
      placeholder = props.placeholder,
      required = props.required,
      readOnly = props.readOnly,
      rest = _objectWithoutProperties(props, ["className", "disabled", "error", "hideErrorMessage", "hideLabel", "id", "label", "onChange", "placeholder", "required", "readOnly"]);

  var renderContent = function renderContent() {
    if (readOnly) {
      return React.createElement("div", _extends({}, rest, {
        className: "slds-form-element__static slds-text-longform"
      }), React.createElement("p", null, placeholder));
    }

    var sldsClasses = ['slds-textarea', className];
    return React.createElement("textarea", _extends({}, rest, {
      className: cx(sldsClasses),
      id: id,
      onChange: onChange,
      placeholder: placeholder,
      disabled: disabled,
      required: required,
      "aria-describedby": error && !hideErrorMessage ? getUniqueHash(error, id) : null
    }));
  };

  return React.createElement(FormElement, {
    className: readOnly ? className : null,
    required: required,
    error: error
  }, React.createElement(FormElementLabel, {
    label: label,
    id: id,
    required: required,
    hideLabel: hideLabel,
    readOnly: readOnly
  }), React.createElement(FormElementControl, {
    className: cx({
      'slds-border_bottom': readOnly
    })
  }, renderContent()), !hideErrorMessage && React.createElement(FormElementError, {
    error: error,
    id: id
  }));
};

Textarea.defaultProps = {
  className: null,
  disabled: null,
  error: null,
  hideErrorMessage: false,
  hideLabel: false,
  onChange: function onChange() {},
  readOnly: false,
  required: false
};
Textarea.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * class name
   */
  className: PropTypes.string,

  /**
  * adds disabled attribute to the textarea
   */
  disabled: PropTypes.bool,

  /**
  * renders an error for the textarea
   */
  error: PropTypes.string,

  /**
   * renders the error message
   */
  hideErrorMessage: PropTypes.bool,

  /**
   * sets the label to render as assistive text
   */
  hideLabel: PropTypes.bool,

  /**
   * id of the textarea
   */
  id: PropTypes.string.isRequired,

  /**
   * label for the textarea
   */
  label: PropTypes.node.isRequired,

  /**
   * onChange handler for the textarea
   */
  onChange: PropTypes.func,

  /**
   * textarea placeholder
   */
  placeholder: PropTypes.string.isRequired,

  /**
   * renders a static textarea output instead
   */
  readOnly: PropTypes.bool,

  /**
   * adds required attribute to the textarea
   */
  required: PropTypes.bool
} : {};
export default Textarea;