import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { applyDecorators, decoratorProp } from '../../utils';
export var gutterSizes = ['xxx-small', 'xx-small', 'x-small', 'small', 'medium', 'large', 'x-large', 'xx-large'];

var Grid = function Grid(props) {
  var align = props.align,
      El = props.as,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      gutters = props.gutters,
      guttersDirect = props.guttersDirect,
      pullPadding = props.pullPadding,
      verticalAlign = props.verticalAlign,
      wrap = props.wrap,
      rest = _objectWithoutProperties(props, ["align", "as", "children", "className", "flavor", "gutters", "guttersDirect", "pullPadding", "verticalAlign", "wrap"]);

  var baseClass = 'slds-grid';
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_align-").concat(align), !!align), _defineProperty({}, "".concat(baseClass, "_vertical-align-").concat(verticalAlign), !!verticalAlign), _defineProperty({}, "".concat(baseClass, "_pull-padded-").concat(pullPadding), !!pullPadding), applyDecorators(flavor, 'grid'), {
    'slds-wrap': !!wrap
  }, className];
  var guttersBaseClass = guttersDirect ? 'slds-gutters_direct' : 'slds-gutters';

  if (gutters === true || guttersDirect === true && gutters === false) {
    sldsClasses.push(guttersBaseClass);
  } else if (gutters && gutters !== true) {
    sldsClasses.push("".concat(guttersBaseClass).concat(guttersDirect ? '-' : '_').concat(gutters));
  }

  return React.createElement(El, _extends({}, rest, {
    className: cx(sldsClasses)
  }), children);
};

Grid.defaultProps = {
  align: null,
  as: 'div',
  children: null,
  className: null,
  gutters: null,
  guttersDirect: false,
  flavor: [],
  pullPadding: null,
  verticalAlign: null,
  wrap: false
};
Grid.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Allows using an arbitrary DOM element as container
   */
  as: PropTypes.string,

  /**
   * grid content
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * flavor: array of flavors, you can also provide a single flavor string.
   * Flavors: frame, vertical, reverse, vertical-reverse
   */
  flavor: decoratorProp(['frame', 'vertical', 'reverse', 'vertical-reverse', 'vertical-stretch']),

  /**
   * Controls how columns are aligned horizontally.
   * Can either either: center, end, space, spread
   */
  align: PropTypes.oneOf(['center', 'end', 'space', 'spread']),

  /**
   * Automatic gutters for all children.
   * Can either be true or any valid slds size string (xxx-small to xx-large)
   */
  gutters: PropTypes.oneOf([true, false].concat(gutterSizes)),

  /**
   * When true, gutters will only be applied to direct children. Use in combination with `gutters`
   */
  guttersDirect: PropTypes.bool,

  /**
   * Controls how columns are aligned vertically.
   * Can either either: center, end, space
   */
  verticalAlign: PropTypes.oneOf(['center', 'end', 'start']),

  /**
   * Normalizes the padding when nesting a grid in a region with .slds-p-horizontal_${size}
   * Note: Not needed when using gutters prop
   */
  pullPadding: PropTypes.oneOf(gutterSizes),

  /**
   * Allows columns to wrap when they exceed 100% of their parent’s width
   * Default Behavior is: Keeps columns on one line.
   */
  wrap: PropTypes.bool
} : {};
export default Grid;