import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { getClampedProgress } from './utils';

var getBarValueStyle = function getBarValueStyle(num, vertical) {
  return _defineProperty({}, vertical ? 'height' : 'width', "".concat(num, "%"));
};

var ProgressBar = function ProgressBar(props) {
  var assistiveLabel = props.assistiveLabel,
      circular = props.circular,
      completeLabel = props.completeLabel,
      className = props.className,
      min = props.min,
      max = props.max,
      progress = props.progress,
      size = props.size,
      success = props.success,
      vertical = props.vertical,
      rest = _objectWithoutProperties(props, ["assistiveLabel", "circular", "completeLabel", "className", "min", "max", "progress", "size", "success", "vertical"]);

  var baseClass = 'slds-progress-bar';
  var sldsClasses = [baseClass, _defineProperty({}, "".concat(baseClass, "_").concat(size), !!size), _defineProperty({}, "".concat(baseClass, "_circular"), circular), _defineProperty({}, "".concat(baseClass, "_vertical"), vertical), className];
  var valueClasses = ["".concat(baseClass, "__value"), _defineProperty({}, "".concat(baseClass, "__value_success"), success)];
  var clampedProgress = getClampedProgress(progress, min, max);
  return React.createElement("div", _extends({}, rest, {
    className: cx(sldsClasses),
    "aria-valuemin": min,
    "aria-valuemax": max,
    "aria-valuenow": clampedProgress,
    role: "progressbar"
  }), React.createElement("span", {
    className: cx(valueClasses),
    style: getBarValueStyle(clampedProgress, vertical)
  }, React.createElement("span", {
    className: "slds-assistive-text"
  }, assistiveLabel ? "".concat(assistiveLabel, ": ").concat(clampedProgress, "%") : "".concat(clampedProgress, "% ").concat(completeLabel))));
};

ProgressBar.defaultProps = {
  assistiveLabel: null,
  completeLabel: 'Complete',
  circular: false,
  className: null,
  progress: 0,
  min: 0,
  max: 100,
  size: null,
  success: false,
  vertical: false
};
ProgressBar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * (DEPRECATED) Assistive label. Interpolates to `${label}: x%`
   */
  assistiveLabel: PropTypes.string,

  /**
   * Assistive label. Interpolates to `x% ${label}`
   */
  completeLabel: PropTypes.string,

  /**
   * Render progress bar with round edges instead
   */
  circular: PropTypes.bool,

  /**
   * (optional) class name
   */
  className: PropTypes.string,

  /**
   * Progress value (between min-max)
   */
  progress: PropTypes.number,

  /**
   * Progress min
   */
  min: PropTypes.number,

  /**
   * Progress max
   */
  max: PropTypes.number,

  /**
   * Available sizes: x-small, small, medium, large
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * Render a green progress bar
   */
  success: PropTypes.bool,

  /**
   * Renders as a vertical progress bar
   */
  vertical: PropTypes.bool
} : {};
export default ProgressBar;