import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var calculateProgressPercent = function calculateProgressPercent(progress, childrenCount) {
  if (progress === 0 || childrenCount === 0) return 0;
  var maxPossibleProgress = Math.min(progress, childrenCount);
  if (maxPossibleProgress >= Math.max(childrenCount - 1, 0)) return 100;
  return maxPossibleProgress / (childrenCount - 1) * 100;
};

var ProgressIndicator = function ProgressIndicator(_ref) {
  var _cx;

  var assistiveText = _ref.assistiveText,
      children = _ref.children,
      className = _ref.className,
      flavor = _ref.flavor,
      isVertical = _ref.isVertical,
      progress = _ref.progress,
      progressLabel = _ref.progressLabel,
      rest = _objectWithoutProperties(_ref, ["assistiveText", "children", "className", "flavor", "isVertical", "progress", "progressLabel"]);

  var progressPercent = calculateProgressPercent(progress, React.Children.count(children));
  var classNames = cx('slds-progress', (_cx = {}, _defineProperty(_cx, "slds-progress_".concat(flavor), flavor), _defineProperty(_cx, 'slds-progress_vertical', isVertical), _cx), className);
  return React.createElement("div", _extends({}, rest, {
    className: classNames
  }), React.createElement("ol", {
    className: "slds-progress__list"
  }, children), React.createElement("div", {
    "aria-valuemin": "0",
    "aria-valuemax": "100",
    "aria-valuenow": progressPercent,
    className: cx({
      'slds-progress-bar slds-progress-bar_x-small': !isVertical
    }),
    role: "progressbar"
  }, isVertical ? React.createElement("span", {
    className: "slds-assistive-text"
  }, progressLabel, progressPercent) : React.createElement("span", {
    className: "slds-progress-bar__value",
    style: {
      width: "".concat(progressPercent, "%")
    }
  }, assistiveText && React.createElement("span", {
    className: "slds-assistive-text"
  }, assistiveText))));
};

ProgressIndicator.defaultProps = {
  assistiveText: null,
  children: null,
  className: null,
  flavor: null,
  isVertical: false,
  progress: 0,
  progressLabel: 'Progress'
};
var propTypes = {
  /**
   * Assistive text for the progress bar
   */
  assistiveText: PropTypes.string,

  /**
   * Progress steps. Need to be ProgressIndicatorItem components
   */
  children: PropTypes.node,

  /**
   * Additional className
   */
  className: PropTypes.string,

  /**
   * Whether the progress indicator should be rendered vertically. This will allow arbitrary
   * item content. Consider using VerticalProgressIndicator instead
   */
  isVertical: PropTypes.bool,

  /**
   * Progress (in no. of completed steps). This affects the progress bar
   */
  progress: PropTypes.number,

  /**
   * Shown as assistive text
   */
  progressLabel: PropTypes.string,

  /**
   * Optional flavor
   */
  flavor: PropTypes.oneOf(['shade'])
};
ProgressIndicator.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export { propTypes };
export default ProgressIndicator;