import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { MediaObject } from '../MediaObject';
import Title from './components/Title';
import TitleRow from './components/TitleRow';

var Tile = function Tile(props) {
  var as = props.as,
      board = props.board,
      children = props.children,
      className = props.className,
      action = props.action,
      figure = props.figure,
      title = props.title,
      titleText = props.titleText,
      rest = _objectWithoutProperties(props, ["as", "board", "children", "className", "action", "figure", "title", "titleText"]);

  var tileClasses = cx(['slds-tile', {
    'slds-tile_board': board
  }, {
    'slds-hint-parent': !!action
  }, className]);
  var tileContent = React.createElement(React.Fragment, null, React.createElement(TitleRow, {
    action: action
  }, React.createElement(Title, {
    title: title,
    titleText: titleText
  })), React.createElement("div", {
    className: "slds-tile__detail"
  }, children));

  if (figure) {
    return React.createElement(MediaObject, _extends({}, rest, {
      as: as,
      center: false,
      className: tileClasses,
      figureLeft: figure
    }), tileContent);
  }

  var El = as;
  return React.createElement(El, _extends({}, rest, {
    className: tileClasses
  }), tileContent);
};

Tile.defaultProps = {
  as: 'article',
  board: false,
  className: null,
  figure: null,
  action: null,
  titleText: ''
};
Tile.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * HTML element name
   */
  as: PropTypes.string,

  /**
   * adds `slds-tile_board` modifier
   */
  board: PropTypes.bool,

  /**
   * `Tile` content
   */
  children: PropTypes.node.isRequired,

  /**
   * additional class names, added to `.slds-tile`
   */
  className: PropTypes.string,

  /**
   * action that renders on the right side of the tile
   */
  action: PropTypes.node,

  /**
   * figure (Icon,Avatar,Checkbox) that renders on the left side of the tile
   */
  figure: PropTypes.node,

  /**
   * title node
   */
  title: PropTypes.node.isRequired,

  /**
   * fallback `title` attribute for `.slds-tile__title` if `title` is not a string
   */
  titleText: PropTypes.string
} : {};
export default Tile;