import "core-js/modules/es.symbol";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Badge } from '../Badge';
import { IconSVG } from '../Icon';

var VerticalNavigationItem = function VerticalNavigationItem(props) {
  var children = props.children,
      className = props.className,
      icon = props.icon,
      isActive = props.isActive,
      notification = props.notification,
      notificationLabel = props.notificationLabel,
      rest = _objectWithoutProperties(props, ["children", "className", "icon", "isActive", "notification", "notificationLabel"]);

  var containerClasses = ['slds-nav-vertical__item', {
    'slds-is-active': isActive
  }];
  var sldsClasses = ['slds-nav-vertical__action', className];

  var renderNotification = function renderNotification() {
    return React.createElement(Badge, {
      className: "slds-col_bump-left",
      title: notificationLabel || "".concat(notification)
    }, "".concat(notification));
  };

  var renderIcon = function renderIcon() {
    var iconName = icon.icon,
        sprite = icon.sprite,
        title = icon.title;
    var iconClasses = ['slds-icon_container', "slds-icon-".concat(sprite, "-").concat(iconName), 'slds-line-height_reset'];
    return React.createElement("span", {
      className: cx(iconClasses),
      title: title
    }, React.createElement(IconSVG, {
      className: "slds-icon-text-default slds-m-right_x-small",
      icon: iconName,
      sprite: sprite,
      size: "x-small"
    }));
  };
  /* eslint-disable jsx-a11y/aria-props */


  return React.createElement("li", {
    className: cx(containerClasses)
  }, React.createElement("a", _extends({
    className: cx(sldsClasses),
    "aria-current": isActive ? 'page' : null
  }, rest), icon && renderIcon(), children, notification != null && renderNotification()));
};

VerticalNavigationItem.defaultProps = {
  className: null,
  icon: null,
  isActive: false,
  notification: null,
  notificationLabel: null
};
VerticalNavigationItem.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Child node, text for default behaviour
   */
  children: PropTypes.node.isRequired,

  /**
   * Classname to be applied to the contained linked element
   */
  className: PropTypes.string,

  /**
   * Icon that will be rendered to the left of children
   */
  icon: PropTypes.shape({
    icon: PropTypes.string,
    sprite: PropTypes.string,
    title: PropTypes.string
  }),

  /**
   * Sets active navigation state
   */
  isActive: PropTypes.bool,

  /**
   * String or number indicating new items
   */
  notification: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),

  /**
   * ARIA-description for the notification
   */
  notificationLabel: PropTypes.string
} : {};
export default VerticalNavigationItem;