import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Button } from '../Button';

var getToggleHandler = function getToggleHandler(state, fn) {
  return function (evt) {
    return fn(!state, evt);
  };
};

var VerticalNavigationOverflow = function VerticalNavigationOverflow(props) {
  var children = props.children,
      className = props.className,
      id = props.id,
      isOpen = props.isOpen,
      labelOpen = props.labelOpen,
      labelClosed = props.labelClosed,
      onToggle = props.onToggle,
      title = props.title,
      rest = _objectWithoutProperties(props, ["children", "className", "id", "isOpen", "labelOpen", "labelClosed", "onToggle", "title"]);

  var renderChild = function renderChild(child) {
    return React.cloneElement(child, {
      'aria-describedby': id
    });
  };

  var sldsClasses = ['slds-nav-vertical__overflow', className];
  return React.createElement("div", _extends({
    className: cx(sldsClasses)
  }, rest), React.createElement(Button, {
    icon: "chevronright",
    sprite: "utility",
    className: "slds-button_reset slds-nav-vertical__action slds-nav-vertical__action_overflow",
    flavor: null,
    onClick: getToggleHandler(isOpen, onToggle),
    "aria-controls": id,
    "aria-expanded": isOpen
  }, React.createElement("span", {
    className: "slds-nav-vertical__action-text"
  }, isOpen ? labelOpen : labelClosed, React.createElement("span", {
    className: "slds-assistive-text"
  }, title))), React.createElement("div", {
    id: id,
    className: isOpen ? 'slds-show' : 'slds-hide'
  }, React.createElement("ul", null, React.Children.map(children, renderChild))));
};

VerticalNavigationOverflow.defaultProps = {
  className: null,
  labelOpen: 'Show less',
  labelClosed: 'Show more'
};
VerticalNavigationOverflow.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * One or more VerticalNavigationItem
   */
  children: PropTypes.node.isRequired,

  /**
   * Classname to be applied to the parent
   */
  className: PropTypes.string,

  /**
   * Id of title, will relate children to parent
   */
  id: PropTypes.string.isRequired,

  /**
   * Button text when open
   */
  labelOpen: PropTypes.string,

  /**
   * Button text when closed
   */
  labelClosed: PropTypes.string,

  /**
   * Open state of overflow
   */
  isOpen: PropTypes.bool.isRequired,

  /**
   * Button click callback, called with: (nextState, evt)
   */
  onToggle: PropTypes.func.isRequired,

  /**
   * Parent section title, accessibility only
   */
  title: PropTypes.string.isRequired
} : {};
export default VerticalNavigationOverflow;